@@ -1,6 +1,6 @@
 # ==========================================================================
 #
-# ZoneMinder Shared Memory Module, $Date: 2006/11/16 11:32:51 $, $Revision: 1.12 $
+# ZoneMinder Shared Memory Module, $Date: 2007-08-29 19:11:09 +0100 (Wed, 29 Aug 2007) $, $Revision: 2175 $
 # Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
 #
 # This program is free software; you can redistribute it and/or
@@ -222,7 +222,7 @@ sub zmShmGet( $ )
 	my $monitor = shift;
 	if ( !defined($monitor->{ShmId}) )
 	{
-		my $shm_key = hex(ZM_SHM_KEY)|$monitor->{Id};
+		my $shm_key = (hex(ZM_SHM_KEY)&0xffff0000)|$monitor->{Id};
 		my $shm_id = shmget( $shm_key, $shm_size, 0 );
 		if ( !defined($shm_id) )
 		{
@@ -806,19 +806,9 @@ Philip Coombes, E<lt>philip.coombes@zoneminder.comE<gt>
 
 Copyright (C) 2005 by Philip Coombes
 
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License
-as published by the Free Software Foundation; either version 2
-of the License, or (at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.8.3 or,
+at your option, any later version of Perl 5 you may have available.
 
 
 =cut
