@@ -2,7 +2,7 @@
 #
 # ==========================================================================
 #
-# ZoneMinder Update Script, $Date: 2006/11/24 14:39:38 $, $Revision: 1.24 $
+# ZoneMinder Update Script, $Date: 2008-03-13 13:44:52 +0000 (Thu, 13 Mar 2008) $, $Revision: 2358 $
 # Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
 #
 # This program is free software; you can redistribute it and/or
@@ -45,7 +45,10 @@ use constant CHECK_INTERVAL => (1*24*60*60); # Interval between version checks
 #
 # ==========================================================================
 
-use ZoneMinder;
+use ZoneMinder::Base qw(:all);
+use ZoneMinder::Config qw(:all);
+use ZoneMinder::Debug qw(:all);
+use ZoneMinder::Database qw(:all);
 use ZoneMinder::ConfigAdmin qw( :functions );
 use POSIX;
 use DBI;
@@ -113,7 +116,7 @@ print( "Update agent starting at ".strftime( '%y/%m/%d %H:%M:%S', localtime() ).
 
 if ( $check && ZM_CHECK_FOR_UPDATES )
 {
-	my $dbh = DBI->connect( "DBI:mysql:database=".ZM_DB_NAME.";host=".ZM_DB_HOST, ZM_DB_USER, ZM_DB_PASS );
+	my $dbh = zmDbConnect();
 
 	my $curr_version = ZM_DYN_CURR_VERSION;
 	my $last_version = ZM_DYN_LAST_VERSION;
@@ -125,10 +128,10 @@ if ( $check && ZM_CHECK_FOR_UPDATES )
 
 		my $sql = "update Config set Value = ? where Name = 'ZM_DYN_CURR_VERSION'";
 		my $sth = $dbh->prepare_cached( $sql ) or die( "Can't prepare '$sql': ".$dbh->errstr() );
-		my $res = $sth->execute( $curr_version ) or die( "Can't execute: ".$sth->errstr() );
+		my $res = $sth->execute( "$curr_version" ) or die( "Can't execute: ".$sth->errstr() );
 	}
+	zmDbDisconnect();
 
-	$dbh->disconnect();
 	while( 1 )
 	{
 		my $now = time();
@@ -159,7 +162,7 @@ if ( $check && ZM_CHECK_FOR_UPDATES )
 
 				Info( "Got version: '".$last_version."'\n" );
 
-				my $dbh = DBI->connect( "DBI:mysql:database=".ZM_DB_NAME.";host=".ZM_DB_HOST, ZM_DB_USER, ZM_DB_PASS );
+				$dbh = zmDbConnect();
 
 				my $lv_sql = "update Config set Value = ? where Name = 'ZM_DYN_LAST_VERSION'";
 				my $lv_sth = $dbh->prepare_cached( $lv_sql ) or die( "Can't prepare '$lv_sql': ".$dbh->errstr() );
@@ -169,7 +172,7 @@ if ( $check && ZM_CHECK_FOR_UPDATES )
 				my $lc_sth = $dbh->prepare_cached( $lc_sql ) or die( "Can't prepare '$lc_sql': ".$dbh->errstr() );
 				my $lc_res = $lc_sth->execute( $last_check ) or die( "Can't execute: ".$lc_sth->errstr() );
 
-				$dbh->disconnect();
+                zmDbDisconnect();
 			}
 			else
 			{
@@ -211,7 +214,7 @@ if ( $zone_fix )
 {
 	require DBI;
 
-	my $dbh = DBI->connect( "DBI:mysql:database=".ZM_DB_NAME.";host=".ZM_DB_HOST, ZM_DB_USER, ZM_DB_PASS );
+	my $dbh = zmDbConnect();
 
 	my $sql = "select Z.*, M.Width as MonitorWidth, M.Height as MonitorHeight from Zones as Z inner join Monitors as M on Z.MonitorId = M.Id where Z.Units = 'Percent'";
 	my $sth = $dbh->prepare_cached( $sql ) or die( "Can't prepare '$sql': ".$dbh->errstr() );
@@ -272,7 +275,9 @@ if ( $version )
 
 		if ( $response =~ /^[yY]$/ )
 		{
-			my $command = "mysqldump -h".ZM_DB_HOST;
+            my ( $host, $port ) = ( ZM_DB_HOST =~ /^([^:]+)(?::(.+))?$/ );
+			my $command = "mysqldump -h".$host;
+            $command .= " -P".$port if defined($port);
 			if ( $db_user )
 			{
 				$command .= " -u".$db_user;
@@ -311,7 +316,9 @@ if ( $version )
 		my $dbh = shift;
 		my $version = shift;
 
-		my $command = "mysql -h".ZM_DB_HOST;
+        my ( $host, $port ) = ( ZM_DB_HOST =~ /^([^:]+)(?::(.+))?$/ );
+		my $command = "mysql -h".$host;
+        $command .= " -P".$port if defined($port);
 		if ( $db_user )
 		{
 			$command .= " -u".$db_user;
@@ -350,7 +357,11 @@ if ( $version )
 
 	print( "\nUpgrading database to version ".ZM_VERSION."\n" );
 
-	my $dbh = DBI->connect( "DBI:mysql:database=".ZM_DB_NAME.";host=".ZM_DB_HOST, ZM_DB_USER, ZM_DB_PASS );
+	# Update config first of all
+	loadConfigFromDB();
+	saveConfigToDB();
+
+	my $dbh = zmDbConnect();
 
 	my $cascade = undef;
 	if ( $cascade || $version eq "1.19.0" )
@@ -636,16 +647,147 @@ if ( $version )
 		patchDB( $dbh, "1.22.2" );
 		$cascade = !undef;
 	}
+	if ( $cascade || $version eq "1.22.3" )
+	{
+		# Patch the database
+		patchDB( $dbh, "1.22.3" );
+
+        # Convert timestamp strings to new format
+        {
+            my $sql = "select * from Monitors";
+            my $sth = $dbh->prepare_cached( $sql ) or die( "Can't prepare '$sql': ".$dbh->errstr() );
+            my $res = $sth->execute() or die( "Can't execute: ".$sth->errstr() );
+            my @db_monitors;
+            while( my $db_monitor = $sth->fetchrow_hashref() )
+            {
+                push( @db_monitors, $db_monitor );
+            }
+            $sth->finish();
+            foreach my $db_monitor ( @db_monitors )
+            {
+                if ( $db_monitor->{LabelFormat} =~ /\%\%s/ )
+                {
+                    $db_monitor->{LabelFormat} =~ s/\%\%s/%N/;
+                    $db_monitor->{LabelFormat} =~ s/\%\%s/%Q/;
+
+                    my $sql = "update Monitors set LabelFormat = ? where Id = ?";
+                    my $sth = $dbh->prepare_cached( $sql ) or die( "Can't prepare '$sql': ".$dbh->errstr() );
+                    my $res = $sth->execute( $db_monitor->{LabelFormat}, $db_monitor->{Id} ) or die( "Can't execute: ".$sth->errstr() );
+                }
+            }
+        }
+
+        # Convert filters to new format
+        {
+            my $sql = "select * from Filters";
+            my $sth = $dbh->prepare_cached( $sql ) or die( "Can't prepare '$sql': ".$dbh->errstr() );
+            my $res = $sth->execute() or die( "Can't execute: ".$sth->errstr() );
+            my @db_filters;
+            while( my $db_filter = $sth->fetchrow_hashref() )
+            {
+                push( @db_filters, $db_filter );
+            }
+            $sth->finish();
+            foreach my $db_filter ( @db_filters )
+            {
+                my %filter_terms;
+                foreach my $filter_parm ( split( '&', $db_filter->{Query} ) )
+                {
+                    my( $key, $value ) = split( '=', $filter_parm, 2 );
+                    if ( $key )
+                    {
+                        $filter_terms{$key} = $value;
+                    }
+                }
+                my $filter = { 'terms' => [] };
+                for ( my $i = 1; $i <= $filter_terms{trms}; $i++ )
+                {
+                    my $term = {};
+                    my $conjunction_name = "cnj$i";
+                    my $obracket_name = "obr$i";
+                    my $cbracket_name = "cbr$i";
+                    my $attr_name = "attr$i";
+                    my $op_name = "op$i";
+                    my $value_name = "val$i";
+
+                    $term->{cnj} = $filter_terms{$conjunction_name} if ( $filter_terms{$conjunction_name} );
+                    $term->{obr} = $filter_terms{$obracket_name} if ( $filter_terms{$obracket_name} );
+                    $term->{attr} = $filter_terms{$attr_name} if ( $filter_terms{$attr_name} );
+                    $term->{val} = $filter_terms{$value_name} if ( defined($filter_terms{$value_name}) );
+                    $term->{op} = $filter_terms{$op_name} if ( $filter_terms{$op_name} );
+                    $term->{cbr} = $filter_terms{$cbracket_name} if ( $filter_terms{$cbracket_name} );
+                    push( @{$filter->{terms}}, $term );
+                }
+                $filter->{sort_field} = $filter_terms{sort_field} if ( $filter_terms{sort_field} );
+                $filter->{sort_asc} = $filter_terms{sort_asc} if ( $filter_terms{sort_asc} );
+                $filter->{limit} = $filter_terms{limit} if ( $filter_terms{limit} );
+
+                my $new_query = 'a:'.int(keys(%$filter)).':{s:5:"terms";a:'.int(@{$filter->{terms}}).':{';
+                my $i = 0;
+                foreach my $term ( @{$filter->{terms}} )
+                {
+                    $new_query .= 'i:'.$i.';a:'.int(keys(%$term)).':{';
+                    while ( my ( $key, $val ) = each( %$term ) )
+                    {
+                        $new_query .= 's:'.length($key).':"'.$key.'";';
+                        $new_query .= 's:'.length($val).':"'.$val.'";';
+                    }
+                    $new_query .= '}';
+                    $i++;
+                }
+                $new_query .= '}';
+                foreach my $field ( "sort_field", "sort_asc", "limit" )
+                {
+                    if ( defined($filter->{$field}) )
+                    {
+                        $new_query .= 's:'.length($field).':"'.$field.'";';
+                        $new_query .= 's:'.length($filter->{$field}).':"'.$filter->{$field}.'";';
+                    }
+                }
+                $new_query .= '}';
+
+                my $sql = "update Filters set Query = ? where Name = ?";
+                my $sth = $dbh->prepare_cached( $sql ) or die( "Can't prepare '$sql': ".$dbh->errstr() );
+                my $res = $sth->execute( $new_query, $db_filter->{Name} ) or die( "Can't execute: ".$sth->errstr() );
+            }
+        }
+
+        # Update the stream quality setting to the old image quality ones
+        {
+            my $dbh = zmDbConnect();
+
+            my $sql = "update Config set Value = ? where Name = 'ZM_JPEG_STREAM_QUALITY'";
+            my $sth = $dbh->prepare_cached( $sql ) or die( "Can't prepare '$sql': ".$dbh->errstr() );
+            my $res = $sth->execute( ZM_JPEG_IMAGE_QUALITY ) or die( "Can't execute: ".$sth->errstr() );
+        }
+		$cascade = !undef;
+	}
+	if ( $cascade || $version eq "1.23.0" )
+	{
+		# Patch the database
+		patchDB( $dbh, "1.23.0" );
+		$cascade = !undef;
+	}
+	if ( $cascade || $version eq "1.23.1" )
+	{
+		# Patch the database
+		patchDB( $dbh, "1.23.1" );
+		$cascade = !undef;
+	}
+	if ( $cascade || $version eq "1.23.2" )
+	{
+		# Patch the database
+		patchDB( $dbh, "1.23.2" );
+		$cascade = !undef;
+	}
 	if ( $cascade )
 	{
 		my $installed_version = ZM_VERSION;
-		my $sql = "update Config set Value = ? where Name = 'ZM_DYN_DB_VERSION'";
+		my $sql = "update Config set Value = ? where Name = ?";
 		my $sth = $dbh->prepare_cached( $sql ) or die( "Can't prepare '$sql': ".$dbh->errstr() );
-		my $res = $sth->execute( $installed_version ) or die( "Can't execute: ".$sth->errstr() );
+		my $res = $sth->execute( "$installed_version", "ZM_DYN_DB_VERSION" ) or die( "Can't execute: ".$sth->errstr() );
+		$res = $sth->execute( "$installed_version", "ZM_DYN_CURR_VERSION" ) or die( "Can't execute: ".$sth->errstr() );
 		$dbh->disconnect();
-		# We've done something so make sure the config is updated too
-		loadConfigFromDB();
-		saveConfigToDB();
 	}
 	else
 	{
