@@ -2,7 +2,7 @@
 #
 # ==========================================================================
 #
-# ZoneMinder X10 Control Script, $Date: 2006/11/16 08:55:05 $, $Revision: 1.16 $
+# ZoneMinder X10 Control Script, $Date: 2008-04-21 15:02:43 +0100 (Mon, 21 Apr 2008) $, $Revision: 2392 $
 # Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
 #
 # This program is free software; you can redistribute it and/or
@@ -169,9 +169,9 @@ sub runServer
 	bind( SERVER, $saddr ) or Fatal( "Can't bind: $!" );
 	listen( SERVER, SOMAXCONN ) or Fatal( "Can't listen: $!" );
 
-	$dbh = DBI->connect( "DBI:mysql:database=".ZM_DB_NAME.";host=".ZM_DB_HOST, ZM_DB_USER, ZM_DB_PASS );
+	$dbh = zmDbConnect();
 
-	$x10 = new X10::ActiveHome( port=>ZM_X10_DEVICE, house_code=>ZM_X10_HOUSE_CODE, debug=>1 );
+	$x10 = new X10::ActiveHome( port=>ZM_X10_DEVICE, house_code=>ZM_X10_HOUSE_CODE, debug=>0 );
 
 	loadTasks();
 
@@ -303,12 +303,12 @@ sub runServer
 				if ( defined( $monitor->{LastState} ) )
 				{
 					my $task_list;
-					if ( $state == STATE_ALARM && $monitor->{LastState} == STATE_IDLE ) # Gone into alarm state
+					if ( ($state == STATE_ALARM || $state == STATE_ALERT) && ($monitor->{LastState} == STATE_IDLE || $monitor->{LastState} == STATE_TAPE) ) # Gone into alarm state
 					{
 						Debug( "Applying ON_list for $monitor_id\n" );
 						$task_list = $monitor->{"ON_list"};
 					}
-					elsif ( $state == STATE_IDLE && $monitor->{LastState} > STATE_IDLE ) # Come out of alarm state
+					elsif ( ($state == STATE_IDLE && $monitor->{LastState} != STATE_IDLE) || ($state == STATE_TAPE && $monitor->{LastState} != STATE_TAPE) ) # Come out of alarm state
 					{
 						Debug( "Applying OFF_list for $monitor_id\n" );
 						$task_list = $monitor->{"OFF_list"};
