@@ -1,5 +1,5 @@
 //
-// ZoneMinder MySQL Implementation, $Date: 2006/01/17 10:56:29 $, $Revision: 1.9 $
+// ZoneMinder MySQL Implementation, $Date: 2007-09-07 16:39:44 +0100 (Fri, 07 Sep 2007) $, $Revision: 2198 $
 // Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -18,6 +18,7 @@
 // 
 
 #include <stdlib.h>
+#include <string.h>
 
 #include "zm.h"
 #include "zm_db.h"
@@ -31,11 +32,26 @@ void zmDbConnect()
 		Error(( "Can't initialise structure: %s", mysql_error( &dbconn ) ));
 		exit( mysql_errno( &dbconn ) );
 	}
-	if ( !mysql_real_connect( &dbconn, ZM_DB_HOST, ZM_DB_USER, ZM_DB_PASS, 0, 0, 0, 0 ) )
-	{
-		Error(( "Can't connect to server: %s", mysql_error( &dbconn ) ));
-		exit( mysql_errno( &dbconn ) );
-	}
+    char dbHost[256];
+    strncpy( dbHost, ZM_DB_HOST, sizeof(dbHost) );
+    if ( char *colon_ptr = strchr( dbHost, '/' ) )
+    {
+        *colon_ptr = '\0';
+        char *dbPort = colon_ptr+1;
+	    if ( !mysql_real_connect( &dbconn, dbHost, ZM_DB_USER, ZM_DB_PASS, 0, atoi(dbPort), 0, 0 ) )
+	    {
+		    Error(( "Can't connect to server: %s", mysql_error( &dbconn ) ));
+		    exit( mysql_errno( &dbconn ) );
+	    }
+    }
+    else
+    {
+	    if ( !mysql_real_connect( &dbconn, ZM_DB_HOST, ZM_DB_USER, ZM_DB_PASS, 0, 0, 0, 0 ) )
+	    {
+		    Error(( "Can't connect to server: %s", mysql_error( &dbconn ) ));
+		    exit( mysql_errno( &dbconn ) );
+	    }
+    }
 	if ( mysql_select_db( &dbconn, ZM_DB_NAME ) )
 	{
 		Error(( "Can't select database: %s", mysql_error( &dbconn ) ));
