@@ -1,5 +1,5 @@
 //
-// ZoneMinder Remote Camera Class Implementation, $Date: 2006/10/18 15:14:10 $, $Revision: 1.39 $
+// ZoneMinder Remote Camera Class Implementation, $Date: 2008-03-13 13:36:12 +0000 (Thu, 13 Mar 2008) $, $Revision: 2357 $
 // Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -112,7 +112,7 @@ void RemoteCamera::Initialise()
 
 	if ( !request[0] )
 	{
-		snprintf( request, sizeof(request), "GET %s HTTP/%s\n", path, config.http_version );
+		snprintf( request, sizeof(request), "GET %s HTTP/%s\r\n", path, config.http_version );
 		snprintf( &(request[strlen(request)]), sizeof(request)-strlen(request), "User-Agent: %s/%s\r\n", config.http_ua, ZM_VERSION );
 		snprintf( &(request[strlen(request)]), sizeof(request)-strlen(request), "Host: %s\r\n", host );
 		snprintf( &(request[strlen(request)]), sizeof(request)-strlen(request), "Connection: Keep-Alive\r\n" );
@@ -291,6 +291,7 @@ int RemoteCamera::GetResponse()
 					int buffer_len = ReadData( buffer );
 					if ( buffer_len < 0 )
 					{
+                        Error(( "Unable to read header data" ));
 						return( -1 );
 					}
 					if ( !header_expr )
@@ -473,6 +474,7 @@ int RemoteCamera::GetResponse()
 							int buffer_len = ReadData( buffer );
 							if ( buffer_len < 0 )
 							{
+                                Error(( "Unable to read content" ));
 								return( -1 );
 							}
 						}
@@ -485,6 +487,7 @@ int RemoteCamera::GetResponse()
 							int buffer_len = ReadData( buffer );
 							if ( buffer_len < 0 )
 							{
+                                Error(( "Unable to read content" ));
 								return( -1 );
 							}
 							static RegExpr *content_expr = 0;
@@ -536,6 +539,11 @@ int RemoteCamera::GetResponse()
 					Debug( 3, ( "Returning %d (%d) bytes of captured content", content_length, buffer.Size() ));
 					return( content_length );
 				}
+                default :
+                {
+                    Error(( "Unexpected content parsing state %d", state ));
+                    break;
+                }
 			}
 		}
 	}
@@ -619,6 +627,7 @@ int RemoteCamera::GetResponse()
 					int buffer_len = ReadData( buffer );
 					if ( buffer_len < 0 )
 					{
+                        Error(( "Unable to read header" ));
 						return( -1 );
 					}
 
@@ -656,7 +665,7 @@ int RemoteCamera::GetResponse()
 						}
 
 						Debug( 6, ( header_ptr ));
-						if ( crlf = mempbrk( header_ptr, "\r\n", header_len ) )
+						if ( ( crlf = mempbrk( header_ptr, "\r\n", header_len ) ) )
 						{
 							headers[n_headers++] = header_ptr;
 
@@ -724,7 +733,7 @@ int RemoteCamera::GetResponse()
 
 						if ( status < 200 || status > 299 )
 						{
-							Error(( "Invalid response status %d: %s", status_code, status_mesg ));
+							Error(( "Invalid response status %s: %s", status_code, status_mesg ));
 							return( -1 );
 						}
 						Debug( 3, ( "Got status '%d' (%s), http version %s", status, status_mesg, http_version ));
@@ -746,7 +755,7 @@ int RemoteCamera::GetResponse()
 						{
 							memset( content_type, 0, sizeof(content_type) );
 							start_ptr = content_type_header + strspn( content_type_header, " " );
-							if ( end_ptr = strchr( start_ptr, ';' ) )
+							if ( ( end_ptr = strchr( start_ptr, ';' ) ) )
 							{
 								strncpy( content_type, start_ptr, end_ptr-start_ptr );
 								Debug( 3, ( "Got content type '%s'", content_type ));
@@ -868,7 +877,7 @@ int RemoteCamera::GetResponse()
 
 						Debug( 6, ( "%d: %s", subheader_len, subheader_ptr ));
 
-						if ( crlf = mempbrk( subheader_ptr, "\r\n", subheader_len ) )
+						if ( ( crlf = mempbrk( subheader_ptr, "\r\n", subheader_len ) ) )
 						{
 							subheaders[n_subheaders++] = subheader_ptr;
 
@@ -905,7 +914,7 @@ int RemoteCamera::GetResponse()
 					
 					if ( all_headers && boundary_header )
 					{
-						char *start_ptr, *end_ptr;
+						char *start_ptr;
 
 						Debug( 3, ( "Got boundary '%s'", boundary_header ));
 
@@ -930,6 +939,7 @@ int RemoteCamera::GetResponse()
 						int buffer_len = ReadData( buffer );
 						if ( buffer_len < 0 )
 						{
+                            Error(( "Unable to read subheader" ));
 							return( -1 );
 						}
 						state = SUBHEADERCONT;
@@ -973,6 +983,7 @@ int RemoteCamera::GetResponse()
 							int buffer_len = ReadData( buffer );
 							if ( buffer_len < 0 )
 							{
+                                Error(( "Unable to read content" ));
 								return( -1 );
 							}
 						}
@@ -987,6 +998,7 @@ int RemoteCamera::GetResponse()
 							int buffer_size = buffer.Size();
 							if ( buffer_len < 0 )
 							{
+                                Error(( "Unable to read content" ));
 								return( -1 );
 							}
 							if ( buffer_len )
@@ -1058,6 +1070,7 @@ int RemoteCamera::PreCapture()
 		Connect();
 		if ( sd < 0 )
 		{
+            Error(( "Unable to connect to camera" ));
 			return( -1 );
 		}
 		mode = SINGLE_IMAGE;
@@ -1067,6 +1080,7 @@ int RemoteCamera::PreCapture()
 	{
 		if ( SendRequest() < 0 )
 		{
+            Error(( "Unable to send request" ));
 			Disconnect();
 			return( -1 );
 		}
@@ -1079,6 +1093,7 @@ int RemoteCamera::PostCapture( Image &image )
 	int content_length = GetResponse();
 	if ( content_length < 0 )
 	{
+        Error(( "Unable to get response" ));
 		Disconnect();
 		return( -1 );
 	}
@@ -1088,6 +1103,7 @@ int RemoteCamera::PostCapture( Image &image )
 		{
 			if ( !image.DecodeJpeg( buffer.Extract( content_length ), content_length ) )
 			{
+                Error(( "Unable to decode jpeg" ));
 				Disconnect();
 				return( -1 );
 			}
@@ -1108,6 +1124,7 @@ int RemoteCamera::PostCapture( Image &image )
 		{
 			if ( !image.Unzip( buffer.Extract( content_length ), content_length ) )
 			{
+			    Error(( "Unable to unzip RGB image" ));
 				Disconnect();
 				return( -1 );
 			}
@@ -1141,7 +1158,6 @@ void RemoteCamera::Base64Encode( const char *in_string, char *out_string )
 		base64_table[i++] = '/';
 	}
 
-	int in_len = strlen( in_string );
 	const char *in_ptr = in_string;
 	char *out_ptr = out_string;
 	while( *in_ptr )
