@@ -1,5 +1,5 @@
 //
-// ZoneMinder Signal Handling Implementation, $Date: 2006/05/24 13:51:23 $, $Revision: 1.3 $
+// ZoneMinder Signal Handling Implementation, $Date: 2008-03-13 13:36:12 +0000 (Thu, 13 Mar 2008) $, $Revision: 2357 $
 // Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -86,7 +86,7 @@ RETSIGTYPE zm_die_handler( int signal )
 	int trace_size = 0;
 
 #if HAVE_STRUCT_SIGCONTEXT_EIP
-	Error(( "Signal address is %p, from %p\n", context.cr2, context.eip ));
+	Error(( "Signal address is %p, from %p\n", (void *)context.cr2, (void *)context.eip ));
 
 	trace_size = backtrace( trace, 16 );
 	// overwrite sigaction with caller's address
