@@ -1,5 +1,5 @@
 //
-// ZoneMinder Zone Class Implementation, $Date: 2006/05/08 12:46:23 $, $Revision: 1.40 $
+// ZoneMinder Zone Class Implementation, $Date: 2008-03-13 13:36:12 +0000 (Thu, 13 Mar 2008) $, $Revision: 2357 $
 // Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -23,7 +23,7 @@
 #include "zm_image.h"
 #include "zm_monitor.h"
 
-void Zone::Setup( Monitor *p_monitor, int p_id, const char *p_label, ZoneType p_type, const Polygon &p_polygon, const Rgb p_alarm_rgb, CheckMethod p_check_method, int p_min_pixel_threshold, int p_max_pixel_threshold, int p_min_alarm_pixels, int p_max_alarm_pixels, const Coord &p_filter_box, int p_min_filter_pixels, int p_max_filter_pixels, int p_min_blob_pixels, int p_max_blob_pixels, int p_min_blobs, int p_max_blobs )
+void Zone::Setup( Monitor *p_monitor, int p_id, const char *p_label, ZoneType p_type, const Polygon &p_polygon, const Rgb p_alarm_rgb, CheckMethod p_check_method, int p_min_pixel_threshold, int p_max_pixel_threshold, int p_min_alarm_pixels, int p_max_alarm_pixels, const Coord &p_filter_box, int p_min_filter_pixels, int p_max_filter_pixels, int p_min_blob_pixels, int p_max_blob_pixels, int p_min_blobs, int p_max_blobs, int p_overload_frames )
 {
 	monitor = p_monitor;
 
@@ -45,8 +45,9 @@ void Zone::Setup( Monitor *p_monitor, int p_id, const char *p_label, ZoneType p_
 	max_blob_pixels = p_max_blob_pixels;
 	min_blobs = p_min_blobs;
 	max_blobs = p_max_blobs;
+	overload_frames = p_overload_frames;
 
-	Debug( 1, ( "Initialised zone %d/%s - %d - %dx%d - Rgb:%06x, CM:%d, MnAT:%d, MxAT:%d, MnAP:%d, MxAP:%d, FB:%dx%d, MnFP:%d, MxFP:%d, MnBS:%d, MxBS:%d, MnB:%d, MxB:%d", id, label, type, polygon.Width(), polygon.Height(), alarm_rgb, check_method, min_pixel_threshold, max_pixel_threshold, min_alarm_pixels, max_alarm_pixels, filter_box.X(), filter_box.Y(), min_filter_pixels, max_filter_pixels, min_blob_pixels, max_blob_pixels, min_blobs, max_blobs ));
+	Debug( 1, ( "Initialised zone %d/%s - %d - %dx%d - Rgb:%06x, CM:%d, MnAT:%d, MxAT:%d, MnAP:%d, MxAP:%d, FB:%dx%d, MnFP:%d, MxFP:%d, MnBS:%d, MxBS:%d, MnB:%d, MxB:%d, OF: %d", id, label, type, polygon.Width(), polygon.Height(), alarm_rgb, check_method, min_pixel_threshold, max_pixel_threshold, min_alarm_pixels, max_alarm_pixels, filter_box.X(), filter_box.Y(), min_filter_pixels, max_filter_pixels, min_blob_pixels, max_blob_pixels, min_blobs, max_blobs, overload_frames ));
 
 	alarmed = false;
 	pixel_diff = 0;
@@ -59,6 +60,8 @@ void Zone::Setup( Monitor *p_monitor, int p_id, const char *p_label, ZoneType p_
 	image = 0;
 	score = 0;
 
+    overload_count = 0;
+
 	pg_image = new Image( monitor->Width(), monitor->Height(), 1 );
 	pg_image->Fill( 0xff, polygon );
 	pg_image->Outline( 0xff, polygon );
@@ -116,12 +119,18 @@ bool Zone::CheckAlarms( const Image *delta_image )
 
 	ResetStats();
 
+    if ( overload_count )
+    {
+        Info(( "In overload mode, %d frames of %d remaining", overload_count, overload_frames ));
+        Debug( 4, ( "In overload mode, %d frames of %d remaining", overload_count, overload_frames ));
+        overload_count--;
+        return( false );
+    }
+
 	delete image;
 	// Get the difference image
 	Image *diff_image = image = new Image( *delta_image );
 	int diff_width = diff_image->Width();
-	int diff_height = diff_image->Height();
-	int diff_stride = diff_width * diff_image->Colours();
 
 	unsigned long pixel_diff_count = 0;
 
@@ -139,6 +148,7 @@ bool Zone::CheckAlarms( const Image *delta_image )
 	int hi_x;
 
 	Debug( 4, ( "Checking alarms for zone %d/%s in lines %d -> %d", id, label, lo_y, hi_y ));
+
 	Debug( 5, ( "Checking for alarmed pixels" ));
 	unsigned char *pdiff, *ppoly;
 	// Create an upper margin
@@ -212,10 +222,19 @@ bool Zone::CheckAlarms( const Image *delta_image )
 		diff_image->WriteJpeg( diag_path );
 	}
 
-	if ( !alarm_pixels ) return( false );
-	if ( min_alarm_pixels && alarm_pixels < min_alarm_pixels ) return( false );
-	if ( max_alarm_pixels && alarm_pixels > max_alarm_pixels ) return( false );
-
+	if ( !alarm_pixels )
+    {
+        return( false );
+    }
+	if ( min_alarm_pixels && (alarm_pixels < min_alarm_pixels) )
+    {
+        return( false );
+    }
+	if ( max_alarm_pixels && (alarm_pixels > max_alarm_pixels) )
+    {
+        overload_count = overload_frames;
+        return( false );
+    }
 	score = (100*alarm_pixels)/polygon.Area();
 	Debug( 5, ( "Current score is %d", score ));
 
@@ -294,9 +313,19 @@ bool Zone::CheckAlarms( const Image *delta_image )
 		}
 		Debug( 5, ( "Got %d filtered pixels, need %d -> %d", alarm_filter_pixels, min_filter_pixels, max_filter_pixels ));
 
-		if ( !alarm_filter_pixels ) return( false );
-		if ( min_filter_pixels && alarm_filter_pixels < min_filter_pixels ) return( false );
-		if ( max_filter_pixels && alarm_filter_pixels > max_filter_pixels ) return( false );
+		if ( !alarm_filter_pixels )
+        {
+            return( false );
+        }
+		if ( min_filter_pixels && (alarm_filter_pixels < min_filter_pixels) )
+        {
+            return( false );
+        }
+		if ( max_filter_pixels && (alarm_filter_pixels > max_filter_pixels) )
+        {
+            overload_count = overload_frames;
+            return( false );
+        }
 
 		score = (100*alarm_filter_pixels)/(polygon.Area());
 		Debug( 5, ( "Current score is %d", score ));
@@ -315,15 +344,13 @@ bool Zone::CheckAlarms( const Image *delta_image )
 			{
 				int lo_x = ranges[py].lo_x;
 				int hi_x = ranges[py].hi_x;
-				int last_lo_x = py>=0?ranges[py-1].lo_x:0;
-				int last_hi_x = py>=0?ranges[py-1].hi_x:0;
 
 				pdiff = diff_image->Buffer( lo_x, y );
 				for ( int x = lo_x; x <= hi_x; x++, pdiff++ )
 				{
 					if ( *pdiff == WHITE )
 					{
-						Debug( 9, ( "Got white pixel at %d,%d (%x)", x, y, pdiff ));
+						Debug( 9, ( "Got white pixel at %d,%d (%p)", x, y, pdiff ));
 						//last_x = (x>lo_x)?*(pdiff-1):0;
 						//last_y = (y>lo_y&&x>=last_lo_x&&x<=last_hi_x)?*(pdiff-diff_width):0;
 						last_x = x>0?*(pdiff-1):0;
@@ -367,7 +394,7 @@ bool Zone::CheckAlarms( const Image *delta_image )
 										spdiff = diff_image->Buffer( lo_sx, sy );
 										for ( int sx = lo_sx; sx <= hi_sx; sx++, spdiff++ )
 										{
-											Debug( 9, ( "Pixel at %d,%d (%x) is %d", sx, sy, spdiff, *spdiff ));
+											Debug( 9, ( "Pixel at %d,%d (%p) is %d", sx, sy, spdiff, *spdiff ));
 											if ( *spdiff == bss->tag )
 											{
 												Debug( 9, ( "Setting pixel" ));
@@ -505,7 +532,10 @@ bool Zone::CheckAlarms( const Image *delta_image )
 				diff_image->WriteJpeg( diag_path );
 			}
 
-			if ( !alarm_blobs ) return( false );
+			if ( !alarm_blobs )
+            {
+                return( false );
+            }
 			alarm_blob_pixels = alarm_filter_pixels;
 			Debug( 5, ( "Got %d raw blob pixels, %d raw blobs, need %d -> %d, %d -> %d", alarm_blob_pixels, alarm_blobs, min_blob_pixels, max_blob_pixels, min_blobs, max_blobs ));
 
@@ -562,9 +592,19 @@ bool Zone::CheckAlarms( const Image *delta_image )
 			}
 			Debug( 5, ( "Got %d blob pixels, %d blobs, need %d -> %d, %d -> %d", alarm_blob_pixels, alarm_blobs, min_blob_pixels, max_blob_pixels, min_blobs, max_blobs ));
 
-			if ( !alarm_blobs ) return( false );
-			if ( min_blobs && alarm_blobs < min_blobs ) return( false );
-			if ( max_blobs && alarm_blobs > max_blobs ) return( false );
+			if ( !alarm_blobs )
+            {
+                return( false );
+            }
+			if ( min_blobs && (alarm_blobs < min_blobs) )
+            {
+                return( false );
+            }
+			if ( max_blobs && (alarm_blobs > max_blobs) )
+            {
+                overload_count = overload_frames;
+                return( false );
+            }
 
 			alarm_lo_x = polygon.HiX()+1;
 			alarm_hi_x = polygon.LoX()-1;
@@ -794,7 +834,7 @@ bool Zone::ParseZoneString( const char *zone_string, int &zone_id, int &colour,
 	char *ws = strchr( str, ' ' );
 	if ( !ws )
 	{
-		Debug( 3, ( "No whitespace found in zone string, finishing", zone_string ));
+		Debug( 3, ( "No whitespace found in zone string '%s', finishing", zone_string ));
 	}
 	zone_id = strtol( str, 0, 10 );
 	Debug( 3, ( "Got zone %d from zone string", zone_id ));
@@ -832,7 +872,7 @@ bool Zone::ParseZoneString( const char *zone_string, int &zone_id, int &colour,
 int Zone::Load( Monitor *monitor, Zone **&zones )
 {
 	static char sql[BUFSIZ];
-	snprintf( sql, sizeof(sql), "select Id,Name,Type+0,Units,NumCoords,Coords,AlarmRGB,CheckMethod+0,MinPixelThreshold,MaxPixelThreshold,MinAlarmPixels,MaxAlarmPixels,FilterX,FilterY,MinFilterPixels,MaxFilterPixels,MinBlobPixels,MaxBlobPixels,MinBlobs,MaxBlobs from Zones where MonitorId = %d order by Type, Id", monitor->Id() );
+	snprintf( sql, sizeof(sql), "select Id,Name,Type+0,Units,NumCoords,Coords,AlarmRGB,CheckMethod+0,MinPixelThreshold,MaxPixelThreshold,MinAlarmPixels,MaxAlarmPixels,FilterX,FilterY,MinFilterPixels,MaxFilterPixels,MinBlobPixels,MaxBlobPixels,MinBlobs,MaxBlobs,OverloadFrames from Zones where MonitorId = %d order by Type, Id", monitor->Id() );
 	if ( mysql_query( &dbconn, sql ) )
 	{
 		Error(( "Can't run query: %s", mysql_error( &dbconn ) ));
@@ -857,7 +897,7 @@ int Zone::Load( Monitor *monitor, Zone **&zones )
 		const char *Name = dbrow[col++];
 		int Type = atoi(dbrow[col++]);
 		const char *Units = dbrow[col++];
-		int NumCoords = atoi(dbrow[col++]);
+		/* int NumCoords = */ atoi(dbrow[col++]);
 		const char *Coords = dbrow[col++];
 		int AlarmRGB = dbrow[col]?atoi(dbrow[col]):0; col++;
 		int CheckMethod = atoi(dbrow[col++]);
@@ -873,6 +913,7 @@ int Zone::Load( Monitor *monitor, Zone **&zones )
 		int MaxBlobPixels = dbrow[col]?atoi(dbrow[col]):0; col++;
 		int MinBlobs = dbrow[col]?atoi(dbrow[col]):0; col++;
 		int MaxBlobs = dbrow[col]?atoi(dbrow[col]):0; col++;
+		int OverloadFrames = dbrow[col]?atoi(dbrow[col]):0; col++;
 
 		Debug( 5, ( "Parsing polygon %s", Coords ));
 		Polygon polygon;
@@ -898,7 +939,7 @@ int Zone::Load( Monitor *monitor, Zone **&zones )
 		}
 		else
 		{
-			zones[i] = new Zone( monitor, Id, Name, (Zone::ZoneType)Type, polygon, AlarmRGB, (Zone::CheckMethod)CheckMethod, MinPixelThreshold, MaxPixelThreshold, MinAlarmPixels, MaxAlarmPixels, Coord( FilterX, FilterY ), MinFilterPixels, MaxFilterPixels, MinBlobPixels, MaxBlobPixels, MinBlobs, MaxBlobs );
+			zones[i] = new Zone( monitor, Id, Name, (Zone::ZoneType)Type, polygon, AlarmRGB, (Zone::CheckMethod)CheckMethod, MinPixelThreshold, MaxPixelThreshold, MinAlarmPixels, MaxAlarmPixels, Coord( FilterX, FilterY ), MinFilterPixels, MaxFilterPixels, MinBlobPixels, MaxBlobPixels, MinBlobs, MaxBlobs, OverloadFrames );
 		}
 	}
 	if ( mysql_errno( &dbconn ) )
