@@ -1,5 +1,5 @@
 //
-// ZoneMinder Capture Daemon, $Date: 2006/10/24 14:37:34 $, $Revision: 1.37 $
+// ZoneMinder Capture Daemon, $Date: 2008-03-13 13:36:12 +0000 (Thu, 13 Mar 2008) $, $Revision: 2357 $
 // Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -187,13 +187,13 @@ int main( int argc, char *argv[] )
 
 	sigset_t block_set;
 	sigemptyset( &block_set );
-	struct sigaction action, old_action;
 
 	sigaddset( &block_set, SIGUSR1 );
 	sigaddset( &block_set, SIGUSR2 );
 
 	if ( monitors[0]->PrimeCapture() < 0 )
 	{
+        Error(( "Failed to prime capture of initial monitor" ));
 		exit( -1 );
 	}
 
@@ -217,7 +217,7 @@ int main( int argc, char *argv[] )
 		{
 			long min_delay = MAXINT;
 
-			gettimeofday( &now, &dummy_tz );
+			gettimeofday( &now, NULL );
 			for ( int j = 0; j < n_monitors; j++ )
 			{
 				if ( last_capture_times[j].tv_sec )
@@ -244,16 +244,18 @@ int main( int argc, char *argv[] )
 			{
 				if ( monitors[i]->PreCapture() < 0 )
 				{
+                    Error(( "Failed to pre-capture monitor %d", i ));
 					exit( -1 );
 				}
 				if ( monitors[i]->PostCapture() < 0 )
 				{
+                    Error(( "Failed to post-capture monitor %d", i ));
 					exit( -1 );
 				}
 
 				if ( next_delays[i] > 0 )
 				{
-					gettimeofday( &now, &dummy_tz );
+					gettimeofday( &now, NULL );
 					DELTA_TIMEVAL( delta_time, now, last_capture_times[i], DT_PREC_3 );
 					long sleep_time = next_delays[i]-delta_time.delta;
 					if ( sleep_time > 0 )
@@ -261,7 +263,7 @@ int main( int argc, char *argv[] )
 						usleep( sleep_time*(DT_MAXGRAN/DT_PREC_3) );
 					}
 				}
-				gettimeofday( &(last_capture_times[i]), &dummy_tz );
+				gettimeofday( &(last_capture_times[i]), NULL );
 			}
 		}
 		sigprocmask( SIG_UNBLOCK, &block_set, 0 );
