@@ -1,5 +1,5 @@
 //
-// ZoneMinder Streaming Server, $Date: 2006/04/05 12:22:27 $, $Revision: 1.44 $
+// ZoneMinder Streaming Server, $Date: 2007-11-20 17:06:45 +0000 (Tue, 20 Nov 2007) $, $Revision: 2245 $
 // Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -17,6 +17,9 @@
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 // 
 
+#include <sys/ipc.h>
+#include <sys/msg.h>
+
 #include "zm.h"
 #include "zm_db.h"
 #include "zm_user.h"
@@ -49,19 +52,23 @@ bool ValidateAccess( User *user, int mon_id )
 
 int main( int argc, const char *argv[] )
 {
+	enum { ZMS_MONITOR, ZMS_EVENT } source = ZMS_MONITOR;
 	enum { ZMS_JPEG, ZMS_MPEG, ZMS_RAW, ZMS_ZIP, ZMS_SINGLE } mode = ZMS_JPEG;
 	char format[32] = "";
-	int id = 0;
-	int event = 0;
-	int frame = 1;
+	int monitor_id = 0;
+	time_t event_time = 0;
+	int event_id = 0;
+	int frame_id = 1;
 	unsigned int scale = 100;
 	unsigned int rate = 100;
 	unsigned int maxfps = 10;
 	unsigned int bitrate = 100000;
 	unsigned int ttl = 0;
+    EventStream::StreamMode replay = EventStream::MODE_SINGLE;
 	char username[64] = "";
 	char password[64] = "";
 	char auth[64] = "";
+    unsigned int connkey = 0;
 
 	bool nph = false;
 	const char *basename = strrchr( argv[0], '/' );
@@ -71,7 +78,7 @@ int main( int argc, const char *argv[] )
 		nph = true;
 	}
 	
-	zmDbgInit( "zms", "", -1 );
+	zmDbgInit( "zms", "", 0 );
 
 	zmLoadConfig();
 
@@ -98,21 +105,29 @@ int main( int argc, const char *argv[] )
 		{
 			char *name = strtok( parms[p], "=" );
 			char *value = strtok( NULL, "=" );
-			if ( !strcmp( name, "mode" ) )
+            if ( !value )
+                value = "";
+			if ( !strcmp( name, "source" ) )
+			{
+				source = !strcmp( value, "event" )?ZMS_EVENT:ZMS_MONITOR;
+			}
+			else if ( !strcmp( name, "mode" ) )
 			{
 				mode = !strcmp( value, "jpeg" )?ZMS_JPEG:ZMS_MPEG;
 				mode = !strcmp( value, "raw" )?ZMS_RAW:mode;
 				mode = !strcmp( value, "zip" )?ZMS_ZIP:mode;
 				mode = !strcmp( value, "single" )?ZMS_SINGLE:mode;
 			}
-			else if ( !strcmp( name, "monitor" ) )
-				id = atoi( value );
-			else if ( !strcmp( name, "event" ) )
-				event = strtoull( value, (char **)NULL, 10 );
-			else if ( !strcmp( name, "frame" ) )
-				frame = strtoull( value, (char **)NULL, 10 );
 			else if ( !strcmp( name, "format" ) )
 				strncpy( format, value, sizeof(format) );
+			else if ( !strcmp( name, "monitor" ) )
+				monitor_id = atoi( value );
+			else if ( !strcmp( name, "time" ) )
+				event_time = atoi( value );
+			else if ( !strcmp( name, "event" ) )
+				event_id = strtoull( value, (char **)NULL, 10 );
+			else if ( !strcmp( name, "frame" ) )
+				frame_id = strtoull( value, (char **)NULL, 10 );
 			else if ( !strcmp( name, "scale" ) )
 				scale = atoi( value );
 			else if ( !strcmp( name, "rate" ) )
@@ -123,6 +138,13 @@ int main( int argc, const char *argv[] )
 				bitrate = atoi( value );
 			else if ( !strcmp( name, "ttl" ) )
 				ttl = atoi(value);
+			else if ( !strcmp( name, "replay" ) )
+			{
+				replay = !strcmp( value, "gapless" )?EventStream::MODE_ALL_GAPLESS:EventStream::MODE_SINGLE;
+				replay = !strcmp( value, "all" )?EventStream::MODE_ALL:replay;
+			}
+			else if ( !strcmp( name, "connkey" ) )
+				connkey = atoi(value);
 			else if ( config.opt_use_auth )
 			{
 				if ( strcmp( config.auth_relay, "none" ) == 0 )
@@ -190,7 +212,7 @@ int main( int argc, const char *argv[] )
 			Error(( "Unable to authenticate user" ));
 			return( -1 );
 		}
-		ValidateAccess( user, id );
+		ValidateAccess( user, monitor_id );
 	}
 
 	setbuf( stdout, 0 );
@@ -215,56 +237,79 @@ int main( int argc, const char *argv[] )
 		//fprintf( stdout, "Content-Length: 0\r\n");
 	//}
 
-	if ( !event )
+	if ( source == ZMS_MONITOR )
 	{
-		Monitor *monitor = Monitor::Load( id );
+        MonitorStream stream;
+        stream.setStreamScale( scale );
+        stream.setStreamReplayRate( rate );
+        stream.setStreamMaxFPS( maxfps );
+        stream.setStreamTTL( ttl );
+        stream.setStreamQueue( connkey );
+        stream.setStreamStart( monitor_id );
 
-		if ( monitor )
+        if ( mode == ZMS_JPEG )
+        {
+            stream.setStreamType( MonitorStream::STREAM_JPEG );
+		}
+		else if ( mode == ZMS_RAW )
 		{
-			if ( mode == ZMS_JPEG )
-			{
-				monitor->StreamImages( scale, maxfps, ttl );
-			}
-			else if ( mode == ZMS_RAW )
-			{
-				monitor->StreamImagesRaw( scale, maxfps, ttl );
-			}
-			else if ( mode == ZMS_ZIP )
-			{
-				monitor->StreamImagesZip( scale, maxfps, ttl );
-			}
-			else if ( mode == ZMS_SINGLE )
-			{
-				monitor->SingleImage( scale );
-			} 
-			else
-			{
+            stream.setStreamType( MonitorStream::STREAM_RAW );
+		}
+		else if ( mode == ZMS_ZIP )
+		{
+            stream.setStreamType( MonitorStream::STREAM_ZIP );
+		}
+		else if ( mode == ZMS_SINGLE )
+		{
+            stream.setStreamType( MonitorStream::STREAM_SINGLE );
+        }
+        else
+        {
 #if HAVE_LIBAVCODEC
-				 monitor->StreamMpeg( format, scale, maxfps, bitrate );
+            stream.setStreamFormat( format );
+            stream.setStreamBitrate( bitrate );
+            stream.setStreamType( MonitorStream::STREAM_MPEG );
 #else // HAVE_LIBAVCODEC
-				Error(( "MPEG streaming of '%s' attempted while disabled", query ));
-				fprintf( stderr, "MPEG streaming is disabled.\nYou should configure with the --with-ffmpeg option and rebuild to use this functionality.\n" );
-				return( -1 );
+            Error(( "MPEG streaming of '%s' attempted while disabled", query ));
+            fprintf( stderr, "MPEG streaming is disabled.\nYou should configure with the --with-ffmpeg option and rebuild to use this functionality.\n" );
+            return( -1 );
 #endif // HAVE_LIBAVCODEC
-			}
-		}
+        }
+        stream.runStream();
 	}
-	else
-	{
-		if ( mode == ZMS_JPEG )
-		{
-			Event::StreamEvent( event, frame, scale, rate, maxfps );
-		}
-		else
-		{
+    else if ( source == ZMS_EVENT )
+    {
+        EventStream stream;
+        stream.setStreamScale( scale );
+        stream.setStreamReplayRate( rate );
+        stream.setStreamMaxFPS( maxfps );
+        stream.setStreamMode( replay );
+        stream.setStreamQueue( connkey );
+        if ( monitor_id && event_time )
+        {
+            stream.setStreamStart( monitor_id, event_time );
+        }
+        else
+        {
+            stream.setStreamStart( event_id, frame_id );
+        }
+        if ( mode == ZMS_JPEG )
+        {
+            stream.setStreamType( EventStream::STREAM_JPEG );
+        }
+        else
+        {
 #if HAVE_LIBAVCODEC
-			Event::StreamMpeg( event, frame, format, scale, rate, maxfps, bitrate );
+            stream.setStreamFormat( format );
+            stream.setStreamBitrate( bitrate );
+            stream.setStreamType( EventStream::STREAM_MPEG );
 #else // HAVE_LIBAVCODEC
-			Error(( "MPEG streaming of '%s' attempted while disabled", query ));
-			fprintf( stderr, "MPEG streaming is disabled.\nYou should configure with the --with-ffmpeg option and rebuild to use this functionality.\n" );
-			return( -1 );
+            Error(( "MPEG streaming of '%s' attempted while disabled", query ));
+            fprintf( stderr, "MPEG streaming is disabled.\nYou should configure with the --with-ffmpeg option and rebuild to use this functionality.\n" );
+            return( -1 );
 #endif // HAVE_LIBAVCODEC
-		}
-	}
+        }
+        stream.runStream();
+    }
 	return( 0 );
 }
