@@ -1,5 +1,5 @@
 //
-// ZoneMinder Control Utility, $Date: 2006/04/05 12:22:27 $, $Revision: 1.55 $
+// ZoneMinder Control Utility, $Date: 2008-02-13 22:44:37 +0000 (Wed, 13 Feb 2008) $, $Revision: 2306 $
 // Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -61,7 +61,7 @@ void Usage( int status=-1 )
 	fprintf( stderr, "  -c, --cancel                   : Cancel a forced alarm/noalarm in monitor, required after being enabled with -a or -n\n" );
 	fprintf( stderr, "  -L, --reload                   : Signal monitor to reload settings\n" );
 	fprintf( stderr, "  -E, --enable                   : Enable detection, wake monitor up\n" );
-	fprintf( stderr, "  -D, --disable                  : Disble detection, put monitor to sleep\n" );
+	fprintf( stderr, "  -D, --disable                  : Disable detection, put monitor to sleep\n" );
 	fprintf( stderr, "  -u, --suspend                  : Suspend detection, useful to prevent bogus alarms when panning etc\n" );
 	fprintf( stderr, "  -r, --resume                   : Resume detection after a suspend\n" );
 	fprintf( stderr, "  -U, --username <username>      : When running in authenticated mode the username and\n" );
@@ -189,7 +189,7 @@ int main( int argc, char *argv[] )
 	{
 		int option_index = 0;
 
-		int c = getopt_long (argc, argv, "d:m:vsEDurwei::S:t::fz::ancqhlB::C::H::O::U:P:A:", long_options, &option_index);
+		int c = getopt_long (argc, argv, "d:m:vsEDLurwei::S:t::fz::ancqhlB::C::H::O::U:P:A:", long_options, &option_index);
 		if (c == -1)
 		{
 			break;
@@ -413,7 +413,7 @@ int main( int argc, char *argv[] )
 	}
 	else if ( mon_id > 0 )
 	{
-		Monitor *monitor = Monitor::Load( mon_id, function&(ZMU_QUERY|ZMU_ZONES) );
+		Monitor *monitor = Monitor::Load( mon_id, function&(ZMU_QUERY|ZMU_ZONES), Monitor::QUERY );
 		if ( monitor )
 		{
 			if ( verbose )
@@ -700,7 +700,7 @@ int main( int argc, char *argv[] )
 				{
 					if ( function > 1 )
 					{
-						Monitor *monitor = Monitor::Load( mon_id );
+						Monitor *monitor = Monitor::Load( mon_id, false, Monitor::QUERY );
 						if ( monitor )
 						{
 							struct timeval tv = monitor->GetTimestamp();
