@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web function library, $Date: 2006/11/09 10:51:10 $, $Revision: 1.87 $
+// ZoneMinder web function library, $Date: 2008-04-15 14:35:20 +0100 (Tue, 15 Apr 2008) $, $Revision: 2386 $
 // Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -37,28 +37,17 @@ function userLogin( $username, $password="" )
 		global $_SESSION, $_SERVER;
 	}
 
-	if ( version_compare( phpversion(), "4.3.0", "<") )
-	{
-		$mysql_username = mysql_escape_string($username);
-		$mysql_password = mysql_escape_string($password);
-	}
-	else
-	{
-		$mysql_username = mysql_real_escape_string($username);
-		$mysql_password = mysql_real_escape_string($password);
-	}
+	$db_username = dbEscape($username);
+	$db_password = dbEscape($password);
 
 	if ( ZM_AUTH_TYPE == "builtin" )
 	{
-		$sql = "select * from Users where Username = '$mysql_username' and Password = password('$mysql_password') and Enabled = 1";
+		$sql = "select * from Users where Username = '$db_username' and Password = password('$db_password') and Enabled = 1";
 	}
 	else
 	{
-		$sql = "select * from Users where Username = '$mysql_username' and Enabled = 1";
+		$sql = "select * from Users where Username = '$db_username' and Enabled = 1";
 	}
-	$result = mysql_query( $sql );
-	if ( !$result )
-		echo mysql_error();
 	$_SESSION['username'] = $username;
 	if ( ZM_AUTH_RELAY == "plain" )
 	{
@@ -66,7 +55,7 @@ function userLogin( $username, $password="" )
 		$_SESSION['password'] = $password;
 	}
 	$_SESSION['remote_addr'] = $_SERVER['REMOTE_ADDR']; // To help prevent session hijacking
-	if ( $db_user = mysql_fetch_assoc( $result ) )
+	if ( $db_user = dbFetchOne( $sql ) )
 	{
 		$_SESSION['user'] = $user = $db_user;
 		if ( ZM_AUTH_TYPE == "builtin" )
@@ -78,8 +67,8 @@ function userLogin( $username, $password="" )
 	{
 		unset( $user );
 	}
-	mysql_free_result( $result );
-	if ( $cookies ) session_write_close();
+	if ( $cookies )
+        session_write_close();
 }
 
 function userLogout()
@@ -157,6 +146,10 @@ function getStreamSrc( $args )
 			$args[] = "user=".$_SESSION['username'];
 		}
 	}
+    if ( $GLOBALS['connkey'] )
+    {   
+        $args[] = "connkey=".$GLOBALS['connkey'];
+    }       
 	if ( ZM_RAND_STREAM )
 	{
 		$args[] = "rand=".time();
@@ -173,6 +166,22 @@ function getStreamSrc( $args )
 	return( $stream_src );
 }
 
+function getMimeType( $file )
+{
+    if ( function_exists('mime_content_type ') )
+    {
+        return( mime_content_type( $file ) );
+    }
+    elseif ( function_exists('finfo_file ') )
+    {
+        $finfo = finfo_open( FILEINFO_MIME );
+        $mimetype = finfo_file( $finfo, $file );
+        finfo_close($finfo);
+        return( $mimetype );
+    }
+    return( trim( exec( 'file -bi '.escapeshellarg( $file ) ) ) );
+}
+
 function outputVideoStream( $src, $width, $height, $name, $format )
 {
 	switch ( $format )
@@ -296,9 +305,15 @@ controller="0">
 
 function outputImageStream( $src, $width, $height, $name="" )
 {
+   if (canStreamIframe()) {
+?>
+<iframe src="<?= $src ?>" alt="<?= $name ?>" border="0" width="<?= $width ?>" height="<?= $height ?>">
+<?php
+   } else {
 ?>
 <img src="<?= $src ?>" alt="<?= $name ?>" border="0" width="<?= $width ?>" height="<?= $height ?>">
 <?php
+   }
 }
 
 function outputControlStream( $src, $width, $height, $monitor, $scale, $target )
@@ -313,19 +328,19 @@ function outputControlStream( $src, $width, $height, $monitor, $scale, $target )
 				if ( $monitor['CanMoveMap'] ) 
 				{
 ?>
-<input type="hidden" name="control" value="move_map">
+<input type="hidden" name="control" value="moveMap">
 <?php
 				}
 				elseif ( $monitor['CanMoveRel'] )
 				{
 ?>
-<input type="hidden" name="control" value="move_pseudo_map">
+<input type="hidden" name="control" value="movePseudoMap">
 <?php
 				}
 				elseif ( $monitor['CanMoveCon'] )
 				{
 ?>
-<input type="hidden" name="control" value="move_con_map">
+<input type="hidden" name="control" value="moveConMap">
 <?php
 				}
 ?>
@@ -367,19 +382,19 @@ function outputControlStill( $src, $width, $height, $monitor, $scale, $target )
 				if ( $monitor['CanMoveMap'] ) 
 				{
 ?>
-<input type="hidden" name="control" value="move_map">
+<input type="hidden" name="control" value="moveMap">
 <?php
 				}
 				elseif ( $monitor['CanMoveRel'] )
 				{
 ?>
-<input type="hidden" name="control" value="move_pseudo_map">
+<input type="hidden" name="control" value="movePseudoMap">
 <?php
 				}
 				elseif ( $monitor['CanMoveCon'] )
 				{
 ?>
-<input type="hidden" name="control" value="move_con_map">
+<input type="hidden" name="control" value="moveConMap">
 <?php
 				}
 ?>
@@ -440,24 +455,52 @@ function canEdit( $area, $mid=false )
 	return( $user[$area] == 'Edit' && ( !$mid || visibleMonitor( $mid ) ) );
 }
 
-function deleteEvent( $eid )
+function getEventPath( $event )
+{
+    if ( ZM_USE_DEEP_STORAGE )
+        $event_path = ZM_DIR_EVENTS.'/'.$event['MonitorId'].'/'.strftime( "%y/%m/%d/%H/%M/%S", strtotime($event['StartTime']) );
+    else
+        $event_path = ZM_DIR_EVENTS.'/'.$event['MonitorId'].'/'.$event['Id'];
+    return( $event_path );
+}
+
+function deleteEvent( $eid, $mid=false )
 {
 	global $user;
 
+    if ( !$mid )
+        $mid = '*';
 	if ( $user['Events'] == 'Edit' && $eid )
 	{
-		$result = mysql_query( "delete from Events where Id = '$eid'" );
-		if ( !$result )
-			die( mysql_error() );
+		dbQuery( "delete from Events where Id = '$eid'" );
 		if ( !ZM_OPT_FAST_DELETE )
 		{
-			$result = mysql_query( "delete from Stats where EventId = '$eid'" );
-			if ( !$result )
-				die( mysql_error() );
-			$result = mysql_query( "delete from Frames where EventId = '$eid'" );
-			if ( !$result )
-				die( mysql_error() );
-			system( escapeshellcmd( "rm -rf ".ZM_DIR_EVENTS."/*/".sprintf( "%d", $eid ) ) );
+			dbQuery( "delete from Stats where EventId = '$eid'" );
+			dbQuery( "delete from Frames where EventId = '$eid'" );
+            if ( ZM_USE_DEEP_STORAGE )
+            {
+                //error_log( "Globbing ".ZM_DIR_EVENTS.'/'.$mid.'/*/*/*/.'.$eid );
+                if ( $id_files = glob( ZM_DIR_EVENTS.'/'.$mid.'/*/*/*/.'.$eid ) )
+                    $event_path = preg_replace( "/\.$eid$/", readlink($id_files[0]), $id_files[0] );
+                //error_log( "Deleting $event_path, not really, id = ".$id_files[0] );
+			    system( escapeshellcmd( "rm -rf ".$event_path ) );
+                unlink( $id_files[0] );
+                $path_parts = explode(  '/', $event_path );
+                for ( $i = count($path_parts)-1; $i >= 2; $i-- )
+                {
+                    $delete_path = join( '/', array_slice( $path_parts, 0, $i ) );
+                    if ( !glob( $delete_path."/*" ) )
+                    {
+                        //error_log( "Removing $delete_path, not really" );
+			            system( escapeshellcmd( "rm -rf ".$delete_path ) );
+                    }
+                }
+            }
+            else
+            {
+		        $event_path = ZM_DIR_EVENTS.'/'.$mid.'/'.$eid;
+			    system( escapeshellcmd( "rm -rf ".$event_path ) );
+            }
 		}
 	}
 }
@@ -489,12 +532,20 @@ function buildSelect( $name, $contents, $behaviours=false )
         global $_SESSION;
     }   
 
-	if ( preg_match( "/^(\w+)\s*\[\s*['\"]?(\w+)[\"']?\s*]$/", $name, $matches ) )
+	if ( preg_match("/^\s*(\w+)\s*(\[.*\])?\s*$/", $name, $matches ) && count($matches) > 2 )
 	{
 		$arr = $matches[1];
-		$idx = $matches[2];
 		global $$arr;
-		$value = ${$arr}[$idx];
+		$value = ${$arr};
+	    if ( !preg_match_all("/\[\s*['\"]?(\w+)[\"']?\s*\]/", $matches[2], $matches ) )
+	    {
+            die( "Can't parse selector '$name'" );
+        }
+        for ( $i = 0; $i < count($matches[1]); $i++ )
+        {
+		    $idx = $matches[1][$i];
+		    $value = $value[$idx];
+        }
 	}
 	else
 	{
@@ -514,11 +565,11 @@ function buildSelect( $name, $contents, $behaviours=false )
 		}
 		else
 		{
-			$behaviour_text = ' onChange="'.$behaviours.'"';
+			$behaviour_text = ' onchange="'.$behaviours.'"';
 		}
 	}
 ?>
-<select name="<?= $name ?>" class="form"<?= $behaviour_text ?>>
+<select name="<?= $name ?>" id="<?= $name ?>" class="form"<?= $behaviour_text ?>>
 <?php
 	foreach ( $contents as $content_value => $content_text )
 	{
@@ -659,6 +710,11 @@ function getBrowser( &$browser, &$version )
 		$version = $log_version[1];
 		$browser = 'safari';
 	}
+        elseif (ereg( 'Konqueror/([0-9.]+)',$_SERVER['HTTP_USER_AGENT'],$log_version))
+        {
+                $version = $log_version[1];
+                $browser = 'konqueror';
+        }
 	elseif (ereg( 'Opera ([0-9].[0-9]{1,2})',$_SERVER['HTTP_USER_AGENT'],$log_version))
 	{
 		$version = $log_version[1];
@@ -683,6 +739,13 @@ function isNetscape()
 	return( $browser == "mozilla" );
 }
 
+function isKonqueror()
+{
+   getBrowser( $browser, $version );
+
+   return( $browser == "konqueror" );
+}
+
 function isInternetExplorer()
 {
 	getBrowser( $browser, $version );
@@ -700,9 +763,14 @@ function isWindows()
 	return ( preg_match( '/Win/', $_SERVER['HTTP_USER_AGENT'] ) );
 }
 
+function canStreamIframe()
+{
+   return (isKonqueror());
+}
+
 function canStreamNative()
 {
-	return( ZM_CAN_STREAM == "yes" || ( ZM_CAN_STREAM == "auto" && isNetscape() ) );
+   return( ZM_CAN_STREAM == "yes" || ( ZM_CAN_STREAM == "auto" && (isNetscape() || isKonqueror()) ) );
 }
 
 function canStreamApplet()
@@ -756,10 +824,7 @@ function zmcControl( $monitor, $mode=false )
 		$sql = "select count(if(Function!='None',1,NULL)) as ActiveCount from Monitors where Id = '".$monitor['Id']."'";
 		$zmc_args = "-m ".$monitor['Id'];
 	}
-	$result = mysql_query( $sql );
-	if ( !$result )
-		echo mysql_error();
-	$row = mysql_fetch_assoc( $result );
+	$row = dbFetchOne( $sql );
 	$active_count = $row['ActiveCount'];
 
 	if ( !$active_count )
@@ -781,10 +846,7 @@ function zmaControl( $monitor, $mode=false )
 	if ( !is_array( $monitor ) )
 	{
 		$sql = "select Id,Function,Enabled from Monitors where Id = '$monitor'";
-		$result = mysql_query( $sql );
-		if ( !$result )
-			echo mysql_error();
-		$monitor = mysql_fetch_assoc( $result );
+		$monitor = dbFetchOne( $sql );
 	}
 	switch ( $monitor['Function'] )
 	{
@@ -925,7 +987,7 @@ function zmaCheck( $monitor )
 
 function getImageSrc( $event, $frame, $scale, $capture_only=false, $overwrite=false )
 {
-	$event_path = ZM_DIR_EVENTS.'/'.$event['MonitorId'].'/'.$event['Id'];
+    $event_path = getEventPath( $event );
 
 	//echo "S:$scale, CO:$capture_only<br>";
 	$capt_image = sprintf( "%0".ZM_EVENT_IMAGE_DIGITS."d-capture.jpg", $frame['FrameId'] );
@@ -943,16 +1005,16 @@ function getImageSrc( $event, $frame, $scale, $capture_only=false, $overwrite=fa
 	$has_anal_image = $alarm_frame && file_exists( $anal_path ) && filesize( $anal_path );
 	$is_anal_image = $has_anal_image && !$capture_only;
 
-	if ( $scale >= 100 || !file_exists( ZM_PATH_NETPBM."/jpegtopnm" ) )
+	if ( $scale >= SCALE_BASE || !file_exists( ZM_PATH_NETPBM."/jpegtopnm" ) )
 	{
 		$image_path = $thumb_path = $is_anal_image?$anal_path:$capt_path;
 	}
 	else
 	{
 		if ( version_compare( phpversion(), "4.3.10", ">=") )
-			$fraction = sprintf( "%.3F", $scale/100 );
+			$fraction = sprintf( "%.3F", $scale/SCALE_BASE );
 		else
-			$fraction = sprintf( "%.3f", $scale/100 );
+			$fraction = sprintf( "%.3f", $scale/SCALE_BASE );
 		$scale = (int)round( $scale );
 
 		$thumb_capt_path = preg_replace( "/\.jpg$/", "-$scale.jpg", $thumb_capt_path );
@@ -1000,10 +1062,7 @@ function getImageSrc( $event, $frame, $scale, $capture_only=false, $overwrite=fa
 function createListThumbnail( $event, $overwrite=false )
 {
 	$sql = "select * from Frames where EventId = '".$event['Id']."' and Score = '".$event['MaxScore']."' order by FrameId limit 0,1";
-	if ( !($result = mysql_query( $sql )) )
-		die( mysql_error() );
-	$frame = mysql_fetch_assoc( $result );
-	mysql_free_result( $result );
+    $frame = dbFetchOne( $sql );
 	$frame_id = $frame['FrameId'];
 
 	if ( ZM_WEB_LIST_THUMB_WIDTH )
@@ -1053,7 +1112,7 @@ function createImage( $monitor, $scale )
 	}
 	chdir( ZM_DIR_IMAGES );
 	$command = getZmuCommand( " -m $monitor -i" );
-	if ( !empty($scale) && $scale < 100 )
+	if ( !empty($scale) && $scale < SCALE_BASE )
 		$command .= " -S $scale";
 	$status = exec( escapeshellcmd( $command ) );
 	chdir( '..' );
@@ -1064,9 +1123,7 @@ function executeFilter( $filter )
 {
 	$command = ZM_PATH_BIN."/zmfilter.pl --filter ".$filter;
 	$result = exec( $command, $output, $status );
-	$result = mysql_query( "delete from Filters where Name like '_TempFilter%'" );
-	if ( !$result )
-	    die( mysql_error() );
+	dbQuery( "delete from Filters where Name like '_TempFilter%'" );
 	return( $status );
 }
 
@@ -1151,7 +1208,8 @@ function parseSort( $save_to_session=false, $term_sep='&' )
 	$sort_order = $sort_asc?"asc":"desc";
 	if ( !$sort_asc ) $sort_asc = 0;
 	$sort_query = $term_sep."sort_field=".$sort_field.$term_sep."sort_asc=".$sort_asc;
-	if ( !isset($limit) ) $limit = "";
+	if ( !isset($limit) )
+        $limit = "";
 	if ( $save_to_session )
 	{
 		$_SESSION['sort_field'] = $sort_field;
@@ -1159,79 +1217,53 @@ function parseSort( $save_to_session=false, $term_sep='&' )
 	}
 }
 
-function parseFilter( $save_to_session=false, $term_sep='&' )
+function parseFilter( &$filter, $save_to_session=false, $term_sep='&' )
 {
-	global $trms; // Inputs
-	global $filter_query, $filter_sql, $filter_fields; // Outputs
 	if ( version_compare( phpversion(), "4.1.0", "<") )
 	{
 		global $_SESSION;
 	}
 
-	$filter_query = ''; 
-	$filter_sql = '';
-	$filter_fields = '';
+	$filter['query'] = ''; 
+	$filter['sql'] = '';
+	$filter['fields'] = '';
 
-	if ( $trms )
+	if ( count($filter['terms']) )
 	{
-		if ( $save_to_session )
+		for ( $i = 0; $i < count($filter['terms']); $i++ )
 		{
-			$_SESSION['trms'] = $trms;
-		}
-		$filter_query .= $term_sep."trms=".$trms;
-		$filter_fields .= '<input type="hidden" name="trms" value="'.$trms.'"/>'."\n";
-
-		for ( $i = 1; $i <= $trms; $i++ )
-		{
-			$conjunction_name = "cnj$i";
-			$obracket_name = "obr$i";
-			$cbracket_name = "cbr$i";
-			$attr_name = "attr$i";
-			$op_name = "op$i";
-			$value_name = "val$i";
-
-			global $$conjunction_name, $$obracket_name, $$cbracket_name, $$attr_name, $$op_name, $$value_name;
-
-			if ( isset($$conjunction_name) )
+			if ( isset($filter['terms'][$i]['cnj']) )
 			{
-				$filter_query .= $term_sep.$conjunction_name."=".$$conjunction_name;
-				$filter_sql .= " ".$$conjunction_name." ";
-				$filter_fields .= '<input type="hidden" name="'.$conjunction_name.'" value="'.$$conjunction_name.'"/>'."\n";
-				if ( $save_to_session )
-				{
-					$_SESSION[$conjunction_name] = $$conjunction_name;
-				}
+				$filter['query'] .= $term_sep."filter[terms][$i][cnj]=".urlencode($filter['terms'][$i]['cnj']);
+				$filter['sql'] .= " ".$filter['terms'][$i]['cnj']." ";
+				$filter['fields'] .= "<input type=\"hidden\" name=\"filter[terms][$i][cnj]\" value=\"".htmlspecialchars($filter['terms'][$i]['cnj'])."\"/>\n";
 			}
-			if ( isset($$obracket_name) )
+			if ( isset($filter['terms'][$i]['obr']) )
 			{
-				$filter_query .= $term_sep.$obracket_name."=".$$obracket_name;
-				$filter_sql .= str_repeat( "(", $$obracket_name );
-				$filter_fields .= '<input type="hidden" name="'.$obracket_name.'" value="'.$$obracket_name.'"/>'."\n";
-				if ( $save_to_session )
-				{
-					$_SESSION[$obracket_name] = $$obracket_name;
-				}
+				$filter['query'] .= $term_sep."filter[terms][$i][obr]=".urlencode($filter['terms'][$i]['obr']);
+				$filter['sql'] .= " ".str_repeat( "(", $filter['terms'][$i]['obr'] )." ";
+				$filter['fields'] .= "<input type=\"hidden\" name=\"filter[terms][$i][obr]\" value=\"".htmlspecialchars($filter['terms'][$i]['obr'])."\"/>\n";
 			}
-			if ( isset($$attr_name) )
+			if ( isset($filter['terms'][$i]['attr']) )
 			{
-				$filter_query .= $term_sep.$attr_name."=".$$attr_name;
-				$filter_fields .= '<input type="hidden" name="'.$attr_name.'" value="'.$$attr_name.'"/>'."\n";
-				switch ( $$attr_name )
+				$filter['query'] .= $term_sep."filter[terms][$i][attr]=".urlencode($filter['terms'][$i]['attr']);
+				$filter['fields'] .= "<input type=\"hidden\" name=\"filter[terms][$i][attr]\" value=\"".htmlspecialchars($filter['terms'][$i]['attr'])."\"/>\n";
+				switch ( $filter['terms'][$i]['attr'] )
 				{
 					case 'MonitorName':
-						$filter_sql .= 'M.'.preg_replace( '/^Monitor/', '', $$attr_name );
+						$filter['sql'] .= 'M.'.preg_replace( '/^Monitor/', '', $filter['terms'][$i]['attr'] );
 						break;
 					case 'DateTime':
-						$filter_sql .= "E.StartTime";
+						$filter['sql'] .= "E.StartTime";
 						break;
 					case 'Date':
-						$filter_sql .= "to_days( E.StartTime )";
+						$filter['sql'] .= "to_days( E.StartTime )";
 						break;
 					case 'Time':
-						$filter_sql .= "extract( hour_second from E.StartTime )";
+						$filter['sql'] .= "extract( hour_second from E.StartTime )";
 						break;
 					case 'Weekday':
-						$filter_sql .= "weekday( E.StartTime )";
+						$filter['sql'] .= "weekday( E.StartTime )";
 						break;
 					case 'Id':
 					case 'Name':
@@ -1245,25 +1277,28 @@ function parseFilter( $save_to_session=false, $term_sep='&' )
 					case 'Cause':
 					case 'Notes':
 					case 'Archived':
-						$filter_sql .= "E.".$$attr_name;
+						$filter['sql'] .= "E.".$filter['terms'][$i]['attr'];
 						break;
 					case 'DiskPercent':
-						$filter_sql .= getDiskPercent();
+						$filter['sql'] .= getDiskPercent();
 						break;
 					case 'DiskBlocks':
-						$filter_sql .= getDiskBlocks();
+						$filter['sql'] .= getDiskBlocks();
+						break;
+					case 'SystemLoad':
+						$filter['sql'] .= getLoad();
 						break;
 				}
 				$value_list = array();
-				foreach ( preg_split( '/["\'\s]*?,["\'\s]*?/', preg_replace( '/^["\']+?(.+)["\']+?$/', '$1', $$value_name ) ) as $value )
+				foreach ( preg_split( '/["\'\s]*?,["\'\s]*?/', preg_replace( '/^["\']+?(.+)["\']+?$/', '$1', $filter['terms'][$i]['val'] ) ) as $value )
 				{
-					switch ( $$attr_name )
+					switch ( $filter['terms'][$i]['attr'] )
 					{
 						case 'MonitorName':
 						case 'Name':
 						case 'Cause':
 						case 'Notes':
-							$value = "'$value'";
+							$value = "'".dbEscape($value)."'";
 							break;
 						case 'DateTime':
 							$value = "'".strftime( STRF_FMT_DATETIME_DB, strtotime( $value ) )."'";
@@ -1278,7 +1313,7 @@ function parseFilter( $save_to_session=false, $term_sep='&' )
 					$value_list[] = $value;
 				}
 
-				switch ( $$op_name )
+				switch ( $filter['terms'][$i]['op'] )
 				{
 					case '=' :
 					case '!=' :
@@ -1286,48 +1321,67 @@ function parseFilter( $save_to_session=false, $term_sep='&' )
 					case '>' :
 					case '<' :
 					case '<=' :
-						$filter_sql .= " ".$$op_name." $value";
+						$filter['sql'] .= " ".$filter['terms'][$i]['op']." $value";
 						break;
 					case '=~' :
-						$filter_sql .= " regexp $value";
+						$filter['sql'] .= " regexp $value";
 						break;
 					case '!~' :
-						$filter_sql .= " not regexp $value";
+						$filter['sql'] .= " not regexp $value";
 						break;
 					case '=[]' :
-						$filter_sql .= " in (".join( ",", $value_list ).")";
+						$filter['sql'] .= " in (".join( ",", $value_list ).")";
 						break;
 					case '![]' :
-						$filter_sql .= " not in (".join( ",", $value_list ).")";
+						$filter['sql'] .= " not in (".join( ",", $value_list ).")";
 						break;
 				}
 
-				$filter_query .= $term_sep.$op_name."=".urlencode($$op_name);
-				$filter_fields .= '<input type="hidden" name="'.$op_name.'" value="'.$$op_name.'"/>'."\n";
-				$filter_query .= $term_sep.$value_name."=".urlencode($$value_name);
-				$filter_fields .= '<input type="hidden" name="'.$value_name.'" value="'.$$value_name.'"/>'."\n";
-				if ( $save_to_session )
-				{
-					$_SESSION[$attr_name] = $$attr_name;
-					$_SESSION[$op_name] = $$op_name;
-					$_SESSION[$value_name] = $$value_name;
-				}
+				$filter['query'] .= $term_sep."filter[terms][$i][op]=".urlencode($filter['terms'][$i]['op']);
+				$filter['fields'] .= "<input type=\"hidden\" name=\"filter[terms][$i][op]\" value=\"".htmlspecialchars($filter['terms'][$i]['op'])."\"/>\n";
+				$filter['query'] .= $term_sep."filter[terms][$i][val]=".urlencode($filter['terms'][$i]['val']);
+				$filter['fields'] .= "<input type=\"hidden\" name=\"filter[terms][$i][val]\" value=\"".htmlspecialchars($filter['terms'][$i]['val'])."\"/>\n";
 			}
-			if ( isset($$cbracket_name) )
+			if ( isset($filter['terms'][$i]['cbr']) )
 			{
-				$filter_query .= $term_sep.$cbracket_name."=".$$cbracket_name;
-				$filter_sql .= str_repeat( ")", $$cbracket_name );
-				$filter_fields .= '<input type="hidden" name="'.$cbracket_name.'" value="'.$$cbracket_name.'"/>'."\n";
-				if ( $save_to_session )
-				{
-					$_SESSION[$cbracket_name] = $$cbracket_name;
-				}
+				$filter['query'] .= $term_sep."filter[terms][$i][cbr]=".urlencode($filter['terms'][$i]['cbr']);
+				$filter['sql'] .= " ".str_repeat( ")", $filter['terms'][$i]['cbr'] )." ";
+				$filter['fields'] .= "<input type=\"hidden\" \"name=filter[terms][$i][cbr]\" value=\"".htmlspecialchars($filter['terms'][$i]['cbr'])."\"/>\n";
 			}
 		}
-		$filter_sql = " and ( $filter_sql )";
+        if ( $filter['sql'] )
+		    $filter['sql'] = " and ( ".$filter['sql']." )";
+		if ( $save_to_session )
+		{
+			$_SESSION['filter'] = $filter;
+		}
 	}
 }
 
+function addFilterTerm( $filter, $position, $term=false )
+{
+    if ( $position < 0 )
+        $position = 0;
+    elseif( $position > count($filter['terms']) )
+        $position = count($filter['terms']);
+    if ( $term && $position == 0 )
+        unset( $term['cnj'] );
+    array_splice( $filter['terms'], $position, 0, array( $term?$term:array() ) );
+    
+    return( $filter );
+}
+
+function delFilterTerm( $filter, $position )
+{
+    if ( $position < 0 )
+        $position = 0;
+    elseif( $position >= count($filter['terms']) )
+        $position = count($filter['terms']);
+    array_splice( $filter['terms'], $position, 1 );
+    
+    return( $filter );
+}
+
 function getLoad()
 {
 	$uptime = shell_exec( 'uptime' );
@@ -1393,23 +1447,17 @@ function verNum( $version )
 
 function fixSequences()
 {
-	$sql = "select * from Monitors order by Sequence asc, Id asc";
-	$result = mysql_query( $sql );
-	if ( !$result )
-		echo mysql_error();
 	$sequence = 1;
-	while ( $monitor = mysql_fetch_assoc( $result ) )
+	$sql = "select * from Monitors order by Sequence asc, Id asc";
+    foreach( dbFetchAll( $sql ) as $monitor )
 	{
 		if ( $monitor['Sequence'] != $sequence )
 		{
 			$sql2 = "update Monitors set Sequence = '".$sequence."' where Id = '".$monitor['Id']."'";
-			$result2 = mysql_query( $sql2 );
-			if ( !$result2 )
-				echo mysql_error();
+            dbQuery( $sql2 );
 		}
 		$sequence++;
 	}
-	mysql_free_result( $result );
 }
 
 function firstSet()
@@ -1780,10 +1828,7 @@ function monitorIdsToNames( $ids )
 	if ( !$mITN_monitors )
 	{
 		$sql = "select Id, Name from Monitors";
-		$result = mysql_query( $sql );
-		if ( !$result )
-			echo mysql_error();
-		while ( $monitor = mysql_fetch_assoc( $result ) )
+        foreach( dbFetchAll( $sql ) as $monitor )
 		{
 			$mITN_monitors[$monitor['Id']] = $monitor;
 		}
@@ -1897,4 +1942,55 @@ function setDeviceStatusX10( $key, $status )
 	return( $status );
 }
 
+function isVector ( &$array )
+{
+    $next_key = 0;
+    foreach ( array_keys($array) as $key )
+    {
+        if ( !is_int( $key ) )
+            return( false );
+        if ( $key != $next_key++ )
+            return( false );
+    }
+    return( true );
+}
+
+function jsValue( &$value )
+{
+    switch ( gettype($value) )
+    {
+        case 'double':
+        case 'integer':
+            return( $value );
+        case 'boolean':
+            return( $value?'true':'false' );
+        case 'string':
+            return( "'".addslashes($value)."'" );
+        case 'NULL':
+            return( 'null' );
+        case 'object':
+            return( "'Object ".addslashes(get_class($value))."'" );
+        case 'array':
+            if ( isVector( $value ) )
+                return( '['.join( ',', array_map( 'jsValue', $value) ).']' );
+            else
+            {
+                $result = '{';
+                foreach ($value as $subkey => $subvalue )
+                {
+                    if ( $result != '{' )
+                        $result .= ',';
+                    $result .= jsValue( $subkey ).':'.jsValue( $subvalue );
+                }
+                return( $result.'}' );
+            }
+        default:
+            return( "'".addslashes(gettype($value))."'" );
+    }
+}
+
+function generateConnKey()
+{
+    return( rand( 1, 999999 ) );
+}
 ?>
