@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web control capabilities view file, $Date: 2006/11/07 12:05:19 $, $Revision: 1.10 $
+// ZoneMinder web control capabilities view file, $Date: 2008-01-08 12:33:11 +0000 (Tue, 08 Jan 2008) $, $Revision: 2281 $
 // Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -40,18 +40,14 @@ if ( !isset($tab) )
 
 if ( !empty($cid) )
 {
-	$result = mysql_query( "select * from Controls where Id = '$cid'" );
-	if ( !$result )
-		die( mysql_error() );
-	$control = mysql_fetch_assoc( $result );
-	mysql_free_result( $result );
+	$control = dbFetchOne( "select * from Controls where Id = '$cid'" );
 }
 else
 {
 	$control = array();
 	$control['Name'] = $zmSlangNew;
 	$control['Type'] = "Local";
-	$control['Command'] = "";
+	$control['Protocol'] = "";
 }
 if ( !isset( $new_control ) )
 {
@@ -145,7 +141,7 @@ if ( $tab != 'main' )
 ?>
 <input type="hidden" name="new_control[Name]" value="<?= $new_control['Name'] ?>">
 <input type="hidden" name="new_control[Type]" value="<?= $new_control['Type'] ?>">
-<input type="hidden" name="new_control[Command]" value="<?= $new_control['Command'] ?>">
+<input type="hidden" name="new_control[Protocol]" value="<?= $new_control['Protocol'] ?>">
 <input type="hidden" name="new_control[CanWake]" value="<?= $new_control['CanWake'] ?>">
 <input type="hidden" name="new_control[CanSleep]" value="<?= $new_control['CanSleep'] ?>">
 <input type="hidden" name="new_control[CanReset]" value="<?= $new_control['CanReset'] ?>">
@@ -297,12 +293,12 @@ switch ( $tab )
 	case 'main' :
 	{
 ?>
-<tr><td align="left" class="text"><?= $zmSlangName ?></td><td align="left" class="text"><input type="text" name="new_control[Name]" value="<?= $new_control['Name'] ?>" size="16" class="form"></td></tr>
+<tr><td align="left" class="text"><?= $zmSlangName ?></td><td align="left" class="text"><input type="text" name="new_control[Name]" value="<?= $new_control['Name'] ?>" size="24" class="form"></td></tr>
 <?php
 		$types = array( 'Local'=>$zmSlangLocal, 'Remote'=>$zmSlangRemote );
 ?>
 <tr><td align="left" class="text"><?= $zmSlangType ?></td><td><?= buildSelect( "new_control[Type]", $types ); ?></td></tr>
-<tr><td align="left" class="text"><?= $zmSlangCommand ?></td><td align="left" class="text"><input type="text" name="new_control[Command]" value="<?= $new_control['Command'] ?>" size="40" class="form"></td></tr>
+<tr><td align="left" class="text"><?= $zmSlangProtocol ?></td><td align="left" class="text"><input type="text" name="new_control[Protocol]" value="<?= $new_control['Protocol'] ?>" size="24" class="form"></td></tr>
 <tr><td align="left" class="text"><?= $zmSlangCanWake ?></td><td align="left" class="text"><input type="checkbox" name="new_control[CanWake]" value="1" class="form-noborder"<?php if ( !empty($new_control['CanWake']) ) { ?> checked<?php } ?>></td></tr>
 <tr><td align="left" class="text"><?= $zmSlangCanSleep ?></td><td align="left" class="text"><input type="checkbox" name="new_control[CanSleep]" value="1" class="form-noborder"<?php if ( !empty($new_control['CanSleep']) ) { ?> checked<?php } ?>></td></tr>
 <tr><td align="left" class="text"><?= $zmSlangCanReset ?></td><td align="left" class="text"><input type="checkbox" name="new_control[CanReset]" value="1" class="form-noborder"<?php if ( !empty($new_control['CanReset']) ) { ?> checked<?php } ?>></td></tr>
