@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web monitor view file, $Date: 2006/11/06 13:56:43 $, $Revision: 1.55 $
+// ZoneMinder web monitor view file, $Date: 2007-12-29 18:48:16 +0000 (Sat, 29 Dec 2007) $, $Revision: 2271 $
 // Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -44,18 +44,10 @@ if ( !isset($tab) )
 
 if ( !empty($mid) )
 {
-	$result = mysql_query( "select * from Monitors where Id = '$mid'" );
-	if ( !$result )
-		die( mysql_error() );
-	$monitor = mysql_fetch_assoc( $result );
-	mysql_free_result( $result );
+    $monitor = dbFetchMonitor( $mid );
 	if ( ZM_OPT_X10 )
 	{
-		$result = mysql_query( "select * from TriggersX10 where MonitorId = '$mid'" );
-		if ( !$result )
-			die( mysql_error() );
-		$x10_monitor = mysql_fetch_assoc( $result );
-		mysql_free_result( $result );
+		$x10_monitor = dbFetchOne( "select * from TriggersX10 where MonitorId = '$mid'" );
 	}
 }
 else
@@ -75,13 +67,14 @@ else
 	$monitor['Width'] = "";
 	$monitor['Height'] = "";
 	$monitor['Orientation'] = "0";
-	$monitor['LabelFormat'] = '%%s - %y/%m/%d %H:%M:%S';
+	$monitor['LabelFormat'] = '%N - %y/%m/%d %H:%M:%S';
 	$monitor['LabelX'] = 0;
 	$monitor['LabelY'] = 0;
 	$monitor['ImageBufferCount'] = 40;
 	$monitor['WarmupCount'] = 25;
 	$monitor['PreEventCount'] = 10;
 	$monitor['PostEventCount'] = 10;
+	$monitor['StreamReplayBuffer'] = 1000;
 	$monitor['AlarmFrameCount'] = 1;
 	$monitor['Controllable'] = 0;
 	$monitor['ControlType'] = 0;
@@ -102,6 +95,7 @@ else
 	$monitor['DefaultView'] = 'Events';
 	$monitor['DefaultRate'] = '100';
 	$monitor['DefaultScale'] = '100';
+	$monitor['SignalCheckColour'] = '#0100BE';
 	$monitor['WebColour'] = 'red';
 	$monitor['Triggers'] = "";
 }
@@ -113,11 +107,7 @@ if ( !isset( $new_monitor ) )
 }
 if ( !empty($preset) )
 {
-	$result = mysql_query( "select Type, Device, Channel, Format, Host, Port, Path, Width, Height, Palette, MaxFPS, Controllable, ControlId, ControlDevice, ControlAddress, DefaultView, DefaultRate, DefaultScale from MonitorPresets where Id = '$preset'" );
-	if ( !$result )
-		die( mysql_error() );
-	$preset = mysql_fetch_assoc( $result );
-	mysql_free_result( $result );
+	$preset = dbFetchOne( "select Type, Device, Channel, Format, Host, Port, Path, Width, Height, Palette, MaxFPS, Controllable, ControlId, ControlDevice, ControlAddress, DefaultRate, DefaultScale from MonitorPresets where Id = '$preset'" );
 	foreach ( $preset as $name=>$value )
 	{
 		if ( isset($value) )
@@ -240,6 +230,10 @@ function validateForm(form)
 	{
 		errors[errors.length] = "<?= $zmSlangBadPostEventCount ?>";
 	}
+	if ( !form.elements['new_monitor[StreamReplayBuffer]'].value || !(parseInt(form.elements['new_monitor[StreamReplayBuffer]'].value) >= 0 ) )
+	{
+		errors[errors.length] = "<?= $zmSlangBadStreamReplayBuffer ?>";
+	}
 	if ( !form.elements['new_monitor[AlarmFrameCount]'].value || !(parseInt(form.elements['new_monitor[AlarmFrameCount]'].value) > 0 ) )
 	{
 		errors[errors.length] = "<?= $zmSlangBadAlarmFrameCount ?>";
@@ -256,6 +250,13 @@ function validateForm(form)
 	{
 		errors[errors.length] = "<?= $zmSlangBadFrameSkip ?>";
 	}
+	if ( form.elements['new_monitor[Type]'].value == 'Local' )
+	{
+	    if ( !form.elements['new_monitor[SignalCheckColour]'].value || !form.elements['new_monitor[SignalCheckColour]'].value.match( /^[#0-9a-zA-Z]+$/ ) )
+	    {
+		    errors[errors.length] = "<?= $zmSlangBadSignalCheckColour ?>";
+	    }
+    }
 	if ( !form.elements['new_monitor[WebColour]'].value || !form.elements['new_monitor[WebColour]'].value.match( /^[#0-9a-zA-Z]+$/ ) )
 	{
 		errors[errors.length] = "<?= $zmSlangBadWebColour ?>";
@@ -280,6 +281,36 @@ function selectLinkedMonitors()
 	newWindow( "<?= $PHP_SELF ?>?view=monitorselect&callForm=<?= urlencode( 'monitor_form' ) ?>&callField=<?= urlencode( 'new_monitor[LinkedMonitors]' ) ?>", "zmLinkedMonitors", <?= $jws['monitorselect']['w'] ?>, <?= $jws['monitorselect']['h'] ?> );
 }
 
+function updateMonitorDimensions( element )
+{
+    var form = element.form;
+    var defaultAspectRatio = '<?= ZM_DEFAULT_ASPECT_RATIO ?>';
+    var widthFactor = parseInt( defaultAspectRatio.replace( /:.*$/, '' ) );
+    var heightFactor = parseInt( defaultAspectRatio.replace( /^.*:/, '' ) );
+
+    if ( form.elements['preserveAspectRatio'].checked )
+    {
+        var monitorWidth = parseInt(form.elements['new_monitor[Width]'].value);
+        var monitorHeight = parseInt(form.elements['new_monitor[Height]'].value);
+        switch( element.name )
+        {
+            case 'new_monitor[Width]':
+                if ( monitorWidth >= 0 )
+                    form.elements['new_monitor[Height]'].value = Math.round((monitorWidth * heightFactor) / widthFactor);
+                else
+                    form.elements['new_monitor[Height]'].value = '';
+                break;
+            case 'new_monitor[Height]':
+                if ( monitorHeight >= 0 )
+                    form.elements['new_monitor[Width]'].value = Math.round((monitorHeight * widthFactor) / heightFactor);
+                else
+                    form.elements['new_monitor[Width]'].value = '';
+                break;
+        }
+    }
+    return( false );
+}
+
 function newWindow(Url,Name,Width,Height)
 {
 	var Win = window.open(Url,Name,"resizable,width="+Width+",height="+Height);
@@ -305,11 +336,8 @@ function loadLocations( form )
 		var option_count = 1;
 <?php
 	$sql = "select * from Controls where Type = '".$monitor['Type']."'";
-	$result = mysql_query( $sql );
-	if ( !$result )
-		die( mysql_error() );
 	$control_types = array( ''=>$zmSlangNone );
-	while( $row = mysql_fetch_assoc( $result ) )
+    foreach( dbFetchAll( $sql ) as $row )
 	{
 		$control_types[$row['Id']] = $row['Name'];
 ?>
@@ -336,7 +364,6 @@ function loadLocations( form )
 		returnLocationSelect.options.length = option_count;
 <?php
 	}
-	mysql_free_result( $result );
 ?>
 	}
 	else
@@ -353,7 +380,7 @@ function loadLocations( form )
 <table border="0" cellspacing="0" cellpadding="0" width="100%">
 <tr>
 <td align="left" class="head"><?= $zmSlangMonitor ?> - <?= $monitor['Name'] ?></td>
-<td align="right" valign="bottom" class="text"><?= makeLink( "javascript: newWindow( '$PHP_SELF?view=monitorpreset&mid=$mid', 'zmMonitorPreset<?= $mid ?>', ".$jws['monitorpreset']['w'].", ".$jws['monitorpreset']['h']." );", $zmSlangPresets, canEdit( 'Monitors' ) ) ?></td>
+<td align="right" valign="bottom" class="text"><?= makeLink( "javascript:newWindow( '$PHP_SELF?view=monitorpreset&mid=$mid', 'zmMonitorPreset$mid', ".$jws['monitorpreset']['w'].", ".$jws['monitorpreset']['h']." );", $zmSlangPresets, canEdit( 'Monitors' ) ) ?></td>
 </tr>
 <tr>
 <td>&nbsp;</td>
@@ -455,6 +482,7 @@ if ( $tab != 'buffers' )
 <input type="hidden" name="new_monitor[WarmupCount]" value="<?= $new_monitor['WarmupCount'] ?>">
 <input type="hidden" name="new_monitor[PreEventCount]" value="<?= $new_monitor['PreEventCount'] ?>">
 <input type="hidden" name="new_monitor[PostEventCount]" value="<?= $new_monitor['PostEventCount'] ?>">
+<input type="hidden" name="new_monitor[StreamReplayBuffer]" value="<?= $new_monitor['StreamReplayBuffer'] ?>">
 <input type="hidden" name="new_monitor[AlarmFrameCount]" value="<?= $new_monitor['AlarmFrameCount'] ?>">
 <?php
 }
@@ -493,6 +521,12 @@ if ( $tab != 'misc' )
 <input type="hidden" name="new_monitor[WebColour]" value="<?= $new_monitor['WebColour'] ?>">
 <?php
 }
+if ( $tab != 'misc' || $new_monitor['Type'] != 'Local' )
+{
+?>
+<input type="hidden" name="new_monitor[SignalCheckColour]" value="<?= $new_monitor['SignalCheckColour'] ?>">
+<?php
+}
 ?>
 <tr>
 <td align="left" class="smallhead" width="50%"><?= $zmSlangParameter ?></td><td align="left" class="smallhead" width="50%"><?= $zmSlangValue ?></td>
@@ -584,8 +618,9 @@ switch ( $tab )
 <?php
 		}
 ?>
-<tr><td align="left" class="text"><?= $zmSlangCaptureWidth ?> (<?= $zmSlangPixels ?>)</td><td align="left" class="text"><input type="text" name="new_monitor[Width]" value="<?= $new_monitor['Width'] ?>" size="4" class="form"></td></tr>
-<tr><td align="left" class="text"><?= $zmSlangCaptureHeight ?> (<?= $zmSlangPixels ?>)</td><td align="left" class="text"><input type="text" name="new_monitor[Height]" value="<?= $new_monitor['Height'] ?>" size="4" class="form"></td></tr>
+<tr><td align="left" class="text"><?= $zmSlangCaptureWidth ?> (<?= $zmSlangPixels ?>)</td><td align="left" class="text"><input type="text" name="new_monitor[Width]" value="<?= $new_monitor['Width'] ?>" size="4" class="form" onkeyup="updateMonitorDimensions(this);"></td></tr>
+<tr><td align="left" class="text"><?= $zmSlangCaptureHeight ?> (<?= $zmSlangPixels ?>)</td><td align="left" class="text"><input type="text" name="new_monitor[Height]" value="<?= $new_monitor['Height'] ?>" size="4" class="form" onkeyup="updateMonitorDimensions(this);"></td></tr>
+<tr><td align="left" class="text"><?= $zmSlangPreserveAspect ?></td><td align="left" class="text"><input type="checkbox" name="preserveAspectRatio" value="1" class="form"/></td></tr> 
 <tr><td align="left" class="text"><?= $zmSlangOrientation ?></td><td align="left" class="text"><select name="new_monitor[Orientation]" class="form"><?php foreach ( $orientations as $name => $value ) { ?><option value="<?= $value ?>"<?php if ( $value == $new_monitor['Orientation'] ) { ?> selected<?php } ?>><?= $name ?></option><?php } ?></select></td></tr>
 <?php
 		break;
@@ -606,6 +641,7 @@ switch ( $tab )
 <tr><td align="left" class="text"><?= $zmSlangWarmupFrames ?></td><td align="left" class="text"><input type="text" name="new_monitor[WarmupCount]" value="<?= $new_monitor['WarmupCount'] ?>" size="4" class="form"></td></tr>
 <tr><td align="left" class="text"><?= $zmSlangPreEventImageBuffer ?></td><td align="left" class="text"><input type="text" name="new_monitor[PreEventCount]" value="<?= $new_monitor['PreEventCount'] ?>" size="4" class="form"></td></tr>
 <tr><td align="left" class="text"><?= $zmSlangPostEventImageBuffer ?></td><td align="left" class="text"><input type="text" name="new_monitor[PostEventCount]" value="<?= $new_monitor['PostEventCount'] ?>" size="4" class="form"></td></tr>
+<tr><td align="left" class="text"><?= $zmSlangStreamReplayBuffer ?></td><td align="left" class="text"><input type="text" name="new_monitor[StreamReplayBuffer]" value="<?= $new_monitor['StreamReplayBuffer'] ?>" size="6" class="form"></td></tr>
 <tr><td align="left" class="text"><?= $zmSlangAlarmFrameCount ?></td><td align="left" class="text"><input type="text" name="new_monitor[AlarmFrameCount]" value="<?= $new_monitor['AlarmFrameCount'] ?>" size="4" class="form"></td></tr>
 <?php
 		break;
@@ -662,7 +698,15 @@ switch ( $tab )
 </select></td></tr>
 <tr><td align="left" class="text"><?= $zmSlangDefaultRate ?></td><td align="left" class="text"><?= buildSelect( "new_monitor[DefaultRate]", $rates ); ?></td></tr>
 <tr><td align="left" class="text"><?= $zmSlangDefaultScale ?></td><td align="left" class="text"><?= buildSelect( "new_monitor[DefaultScale]", $scales ); ?></td></tr>
-<tr><td align="left" class="text"><?= $zmSlangWebColour ?></td><td align="left" class="text"><input type="text" name="new_monitor[WebColour]" value="<?= $new_monitor['WebColour'] ?>" size="10" class="form" onChange="document.getElementById('Swatch').style.backgroundColor=this.value">&nbsp;&nbsp;<span id="Swatch" style="background-color: <?= $new_monitor['WebColour'] ?>; border: 1px solid black; width: 20px; height: 10px; padding: 0px;">&nbsp;&nbsp;&nbsp;&nbsp;</span></td></tr>
+<?php
+		if ( $new_monitor['Type'] == "Local" )
+		{
+?>
+<tr><td align="left" class="text"><?= $zmSlangSignalCheckColour ?></td><td align="left" class="text"><input type="text" name="new_monitor[SignalCheckColour]" value="<?= $new_monitor['SignalCheckColour'] ?>" size="10" class="form" onChange="document.getElementById('SignalCheckSwatch').style.backgroundColor=this.value">&nbsp;&nbsp;<span id="SignalCheckSwatch" style="background-color: <?= $new_monitor['SignalCheckColour'] ?>; border: 1px solid black; width: 20px; height: 10px; padding: 0px;">&nbsp;&nbsp;&nbsp;&nbsp;</span></td></tr>
+<?php
+        }
+?>
+<tr><td align="left" class="text"><?= $zmSlangWebColour ?></td><td align="left" class="text"><input type="text" name="new_monitor[WebColour]" value="<?= $new_monitor['WebColour'] ?>" size="10" class="form" onChange="document.getElementById('WebSwatch').style.backgroundColor=this.value">&nbsp;&nbsp;<span id="WebSwatch" style="background-color: <?= $new_monitor['WebColour'] ?>; border: 1px solid black; width: 20px; height: 10px; padding: 0px;">&nbsp;&nbsp;&nbsp;&nbsp;</span></td></tr>
 <?php
 		break;
 	}
