@@ -1,7 +1,6 @@
 <?php
 //
-// ZoneMinder web timeline view file, $Date: 2006/11/16 11:36:10 $, $Revision: 1.20 $
-// Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
+// ZoneMinder web timeline view file, $Date: 2008-02-10 22:13:16 +0000 (Sun, 10 Feb 2008) $, $Revision: 2293 $
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -132,10 +131,8 @@ $chart = array(
 
 $monitors = array();
 $monitors_sql = "select * from Monitors order by Sequence asc";
-if ( !($result = mysql_query( $monitors_sql )) )
-	die( mysql_error() );
 //srand( 97981 );
-while ( $row = mysql_fetch_assoc( $result ) )
+foreach( dbFetchAll( $monitors_sql ) as $row )
 {
 	//if ( empty($row['WebColour']) )
 	//{
@@ -143,7 +140,6 @@ while ( $row = mysql_fetch_assoc( $result ) )
 	//}
 	$monitors[$row['Id']] = $row;
 }
-mysql_free_result( $result );
 
 $range_sql = "select min(E.StartTime) as MinTime, max(E.EndTime) as MaxTime from Events as E inner join Monitors as M on (E.MonitorId = M.Id) where not isnull(E.StartTime) and not isnull(E.EndTime)";
 $events_sql = "select E.Id,E.Name,E.StartTime,E.EndTime,E.Length,E.Frames,E.MaxScore,E.Cause,E.Notes,E.Archived,E.MonitorId from Events as E inner join Monitors as M on (E.MonitorId = M.Id) where not isnull(StartTime)";
@@ -156,7 +152,10 @@ if ( !empty($user['MonitorIds']) )
 	$events_sql .= $mon_filter_sql;
 }
 
-$tree = parseFilterToTree();
+if ( isset($filter) )
+    $tree = parseFilterToTree( $filter );
+else
+    $tree = false;
 
 if ( isset($range) )
 {
@@ -214,14 +213,9 @@ if ( isset($min_time) && isset($max_time) )
 }
 else
 {
-	//$filter_query = parseTreeToQuery( $tree );
-	//echo $filter_query;
-	//echo '<br>';
 	$filter_sql = parseTreeToSQL( $tree );
 	$temp_min_time = $temp_max_time = $temp_expandable = false;
 	extractDatetimeRange( $tree, $temp_min_time, $temp_max_time, $temp_expandable );
-	//echo $filter_sql;
-	//echo '<br>';
 
 	if ( $filter_sql )
 	{
@@ -233,10 +227,7 @@ else
 	if ( !isset($min_time) || !isset($max_time) )
 	{
 		// Dynamically determine range
-		if ( !($result = mysql_query( $range_sql )) )
-			die( mysql_error() );
-		$row = mysql_fetch_assoc( $result );
-		mysql_free_result( $result );
+        $row = dbFetchOne( $range_sql );
 
 		if ( !isset($min_time) )
 			$min_time = $row['MinTime'];
@@ -260,15 +251,16 @@ else
 }
 
 //echo "MnT: $temp_min_time, MxT: $temp_max_time, ExP: $temp_expandable<br>";
-appendDatetimeRange( $tree, $min_time, $max_time );
-
-$filter_query = parseTreeToQuery( $tree );
-if ( $filter_query )
+if ( $tree )
 {
-	$filter_query = '&'.$filter_query;
+    appendDatetimeRange( $tree, $min_time, $max_time );
+
+    $filter_query = parseTreeToQuery( $tree );
+    if ( $filter_query )
+    {
+	    $filter_query = '&'.$filter_query;
+    }
 }
-//echo $filter_query;
-//echo '<br>';
 
 $scales = array(
 	array( "name"=>"year",     "factor"=>60*60*24*365, "align"=>1,  "zoomout"=>2, "label"=>STRF_TL_AXIS_LABEL_YEAR ),
@@ -329,10 +321,8 @@ $chart['data']['x']['density'] = $chart['data']['x']['range']/$chart['graph']['w
 
 $mon_event_slots = array();
 $mon_frame_slots = array();
-if ( !($event_result = mysql_query( $events_sql )) )
-	die( mysql_error() );
 $monitor_ids = array();
-while( $event = mysql_fetch_assoc( $event_result ) )
+foreach( dbFetchAll( $events_sql ) as $event )
 {
 	if ( !isset($monitor_ids[$event['MonitorId']]) )
 		$monitor_ids[$event['MonitorId']] = true;
@@ -407,9 +397,7 @@ while( $event = mysql_fetch_assoc( $event_result ) )
 		else
 		{
 			$frames_sql = "select F.FrameId,F.Delta,unix_timestamp(F.TimeStamp) as TimeT,F.Score from Frames as F where F.EventId = '".$event['Id']."' and F.Score > 0";
-			if ( !($frame_result = mysql_query( $frames_sql )) )
-				die( mysql_error() );
-			while( $frame = mysql_fetch_assoc( $frame_result ) )
+            foreach( dbFetchAll( $frames_sql ) as $frame )
 			{
 				$frame_time_t = $frame['TimeT'];
 				$frame_time_t = $start_time_t + $frame['Delta'];
@@ -438,11 +426,9 @@ while( $event = mysql_fetch_assoc( $event_result ) )
 					$chart['data']['y']['hi'] = $frame['Score'];
 				}
 			}
-			mysql_free_result( $frame_result );
 		}
 	}
 }
-mysql_free_result( $event_result );
 
 ksort($monitor_ids,SORT_NUMERIC);
 ksort($mon_event_slots,SORT_NUMERIC);
@@ -462,10 +448,7 @@ foreach( array_keys($mon_frame_slots) as $monitor_id )
 			{
 				$xcount++;
 				$frames_sql = "select F.FrameId,F.Score from Frames as F where F.EventId = '".$curr_frame_slots[$i]['event']['Id']."' and F.Score > 0 order by F.FrameId limit 0,1";
-				if ( !($frame_result = mysql_query( $frames_sql )) )
-					die( mysql_error() );
-				$curr_frame_slots[$i]['frame'] = mysql_fetch_assoc( $frame_result );
-				mysql_free_result( $frame_result );
+				$curr_frame_slots[$i]['frame'] = dbFetchOne( $frames_sql );
 			}
 		}
 	}
@@ -651,7 +634,6 @@ function getYScale( $range, $min_lines, $max_lines )
 
 function drawXGrid( $chart, $scale, $label_class, $tick_class, $grid_class, $zoom_class=0 )
 {
-	global $PHP_SELF, $view, $filter_query;
 	global $zmSlangZoomIn;
 
 	ob_start();
@@ -763,7 +745,7 @@ function getSlotLoadImageBehaviour( $slot )
 	global $monitors, $jws, $PHP_SELF;
 	global $zmSlangArchived;
 
-	$event_path = ZM_DIR_EVENTS.'/'.$slot['event']['MonitorId'].'/'.$slot['event']['Id'];
+    $event_path = getEventPath( $slot['event'] );
 	$image_path = sprintf( "%s/%0".ZM_EVENT_IMAGE_DIGITS."d-capture.jpg", $event_path, isset($slot['frame'])?$slot['frame']['FrameId']:1 );
 	$anal_image = preg_replace( "/capture/", "analyse", $image_path );
 	if ( file_exists( $anal_image ) )
@@ -1363,11 +1345,9 @@ foreach( array_keys($mon_event_slots) as $monitor_id )
 </html>
 <?php
 
-function parseFilterToTree()
+function parseFilterToTree( $filter )
 {
-	global $trms;
-
-	if ( $trms > 0 )
+	if ( count($filter['terms']) > 0 )
 	{
 		$postfix_expr = array();
 		$postfix_stack = array();
@@ -1387,34 +1367,25 @@ function parseFilterToTree()
 			'or' => 4,
 		);
 
-		for ( $i = 1; $i <= $trms; $i++ )
+		for ( $i = 0; $i <= count($filter['terms']); $i++ )
 		{
-			$conjunction_name = "cnj$i";
-			$obracket_name = "obr$i";
-			$cbracket_name = "cbr$i";
-			$attr_name = "attr$i";
-			$op_name = "op$i";
-			$value_name = "val$i";
-
-			global $$conjunction_name, $$obracket_name, $$cbracket_name, $$attr_name, $$op_name, $$value_name;
-
-			if ( !empty($$conjunction_name) )
+			if ( !empty($filter['terms'][$i]['cnj']) )
 			{
 				while( true )
 				{
 					if ( !count($postfix_stack) )
 					{
-						$postfix_stack[] = array( 'type'=>"cnj", 'value'=>$$conjunction_name, 'sql_value'=>$$conjunction_name );
+						$postfix_stack[] = array( 'type'=>"cnj", 'value'=>$filter['terms'][$i]['cnj'], 'sql_value'=>$filter['terms'][$i]['cnj']);
 						break;
 					}
 					elseif ( $postfix_stack[count($postfix_stack)-1]['type'] == 'obr' )
 					{
-						$postfix_stack[] = array( 'type'=>"cnj", 'value'=>$$conjunction_name, 'sql_value'=>$$conjunction_name );
+						$postfix_stack[] = array( 'type'=>"cnj", 'value'=>$filter['terms'][$i]['cnj'], 'sql_value'=>$filter['terms'][$i]['cnj']);
 						break;
 					}
-					elseif ( $priorities[$$conjunction_name] < $priorities[$postfix_stack[count($postfix_stack)-1]['value']] )
+					elseif ( $priorities[$filter['terms'][$i]['cnj']] < $priorities[$postfix_stack[count($postfix_stack)-1]['value']] )
 					{
-						$postfix_stack[] = array( 'type'=>"cnj", 'value'=>$$conjunction_name, 'sql_value'=>$$conjunction_name );
+						$postfix_stack[] = array( 'type'=>"cnj", 'value'=>$filter['terms'][$i]['cnj'], 'sql_value'=>$filter['terms'][$i]['cnj']);
 						break;
 					}
 					else
@@ -1423,20 +1394,20 @@ function parseFilterToTree()
 					}
 				}
 			}
-			if ( !empty($$obracket_name) )
+			if ( !empty($filter['terms'][$i]['obr']) )
 			{
-				for ( $j = 0; $j < $$obracket_name; $j++ )
+				for ( $j = 0; $j < $filter['terms'][$i]['obr']; $j++ )
 				{
-					$postfix_stack[] = array( 'type'=>"obr", 'value'=>$$obracket_name );
+					$postfix_stack[] = array( 'type'=>"obr", 'value'=>$filter['terms'][$i]['obr']);
 				}
 			}
-			if ( !empty($$attr_name) )
+			if ( !empty($filter['terms'][$i]['attr']) )
 			{
 				$dt_attr = false;
-				switch ( $$attr_name )
+				switch ( $filter['terms'][$i]['attr'])
 				{
 					case 'MonitorName':
-						$sql_value = 'M.'.preg_replace( '/^Monitor/', '', $$attr_name );
+						$sql_value = 'M.'.preg_replace( '/^Monitor/', '', $filter['terms'][$i]['attr']);
 						break;
 					case 'Name':
 						$sql_value = "E.Name";
@@ -1468,7 +1439,7 @@ function parseFilterToTree()
 					case 'AvgScore':
 					case 'MaxScore':
 					case 'Archived':
-						$sql_value = "E.".$$attr_name;
+						$sql_value = "E.".$filter['terms'][$i]['attr'];
 						break;
 					case 'DiskPercent':
 						$sql_value = getDiskPercent();
@@ -1477,25 +1448,25 @@ function parseFilterToTree()
 						$sql_value = getDiskBlocks();
 						break;
 					default :
-						$sql_value = $$attr_name;
+						$sql_value = $filter['terms'][$i]['attr'];
 						break;
 				}
 				if ( $dt_attr )
 				{
-					$postfix_expr[] = array( 'type'=>"attr", 'value'=>$$attr_name, 'sql_value'=>$sql_value, 'dt_attr'=>true );
+					$postfix_expr[] = array( 'type'=>"attr", 'value'=>$filter['terms'][$i]['attr'], 'sql_value'=>$sql_value, 'dt_attr'=>true );
 				}
 				else
 				{
-					$postfix_expr[] = array( 'type'=>"attr", 'value'=>$$attr_name, 'sql_value'=>$sql_value );
+					$postfix_expr[] = array( 'type'=>"attr", 'value'=>$filter['terms'][$i]['attr'], 'sql_value'=>$sql_value );
 				}
 			}
-			if ( isset($$op_name) )
+			if ( isset($filter['terms'][$i]['op']) )
 			{
-				if ( empty($$op_name) )
+				if ( empty($filter['terms'][$i]['op']) )
 				{
-					$$op_name = '=';
+					$filter['terms'][$i]['op' ]= '=';
 				}
-				switch ( $$op_name )
+				switch ( $filter['terms'][$i]['op' ])
 				{
 					case '=' :
 					case '!=' :
@@ -1503,7 +1474,7 @@ function parseFilterToTree()
 					case '>' :
 					case '<' :
 					case '<=' :
-						$sql_value = $$op_name;
+						$sql_value = $filter['terms'][$i]['op'];
 						break;
 					case '=~' :
 						$sql_value = "regexp";
@@ -1522,17 +1493,17 @@ function parseFilterToTree()
 				{
 					if ( !count($postfix_stack) )
 					{
-						$postfix_stack[] = array( 'type'=>"op", 'value'=>$$op_name, 'sql_value'=>$sql_value );
+						$postfix_stack[] = array( 'type'=>"op", 'value'=>$filter['terms'][$i]['op'], 'sql_value'=>$sql_value );
 						break;
 					}
 					elseif ( $postfix_stack[count($postfix_stack)-1]['type'] == 'obr' )
 					{
-						$postfix_stack[] = array( 'type'=>"op", 'value'=>$$op_name, 'sql_value'=>$sql_value );
+						$postfix_stack[] = array( 'type'=>"op", 'value'=>$filter['terms'][$i]['op'], 'sql_value'=>$sql_value );
 						break;
 					}
-					elseif ( $priorities[$$op_name] < $priorities[$postfix_stack[count($postfix_stack)-1]['value']] )
+					elseif ( $priorities[$filter['terms'][$i]['op']] < $priorities[$postfix_stack[count($postfix_stack)-1]['value']] )
 					{
-						$postfix_stack[] = array( 'type'=>"op", 'value'=>$$op_name, 'sql_value'=>$sql_value );
+						$postfix_stack[] = array( 'type'=>"op", 'value'=>$filter['terms'][$i]['op'], 'sql_value'=>$sql_value );
 						break;
 					}
 					else
@@ -1541,12 +1512,12 @@ function parseFilterToTree()
 					}
 				}
 			}
-			if ( isset($$value_name) )
+			if ( isset($filter['terms'][$i]['val']) )
 			{
 				$value_list = array();
-				foreach ( preg_split( '/["\'\s]*?,["\'\s]*?/', preg_replace( '/^["\']+?(.+)["\']+?$/', '$1', $$value_name ) ) as $value )
+				foreach ( preg_split( '/["\'\s]*?,["\'\s]*?/', preg_replace( '/^["\']+?(.+)["\']+?$/', '$1', $filter['terms'][$i]['val' ]) ) as $value )
 				{
-					switch ( $$attr_name )
+					switch ( $filter['terms'][$i]['attr'])
 					{
 						case 'MonitorName':
 						case 'Name':
@@ -1568,11 +1539,11 @@ function parseFilterToTree()
 					}
 					$value_list[] = $value;
 				}
-				$postfix_expr[] = array( 'type'=>"val", 'value'=>$$value_name, 'sql_value'=>join( ',', $value_list ) );
+				$postfix_expr[] = array( 'type'=>"val", 'value'=>$filter['terms'][$i]['val'], 'sql_value'=>join( ',', $value_list ) );
 			}
-			if ( !empty($$cbracket_name) )
+			if ( !empty($filter['terms'][$i]['cbr']) )
 			{
-				for ( $j = 0; $j < $$cbracket_name; $j++ )
+				for ( $j = 0; $j < $filter['terms'][$i]['cbr']; $j++ )
 				{
 					while ( count($postfix_stack) )
 					{
@@ -1686,53 +1657,47 @@ function parseTreeToSQL( $tree )
 	return( _parseTreeToSQL( $tree ) );
 }
 
-function _parseTreeToQuery( $node, &$level )
+function _parseTreeToFilter( $node, &$terms, &$level )
 {
 	$elements = array();
 	if ( $node )
 	{
 		if ( isset($node['left']) )
 		{
-			$elements[] = array( 'name'=>'obr'.$level, 'value'=>!empty($node['data']['bracket'])?1:0 );
-			$elements = array_merge( $elements, _parseTreeToQuery( $node['left'], $level ) );
+            if ( !empty($node['data']['bracket']) )
+                $terms[$level]['obr'] = 1;
+			_parseTreeToFilter( $node['left'], $terms, $level );
 		}
 		if ( $node['data']['type'] == 'cnj' )
 		{
 			$level++;
 		}
-		$elements[] = array( 'name'=>$node['data']['type'].$level, 'value'=>urlencode($node['data']['value']) );
+		$terms[$level][$node['data']['type']] = $node['data']['value'];
 		if ( isset($node['right']) )
 		{
-			$elements = array_merge( $elements, _parseTreeToQuery( $node['right'], $level ) );
-			$elements[] = array( 'name'=>'cbr'.$level, 'value'=>!empty($node['data']['bracket'])?1:0 );
+			_parseTreeToFilter( $node['right'], $terms, $level );
+            if ( !empty($node['data']['bracket']) )
+                $terms[$level]['cbr'] = 1;
 		}
 	}
-	return( $elements );
+}
+
+function parseTreeToFilter( $tree )
+{
+    $terms = array();
+	if ( isset($tree) )
+	{
+		$level = 0;
+		_parseTreeToFilter( $tree, $terms, $level );
+	}
+	return( array( 'terms' => $terms ) );
 }
 
 function parseTreeToQuery( $tree )
 {
-	$query = '';
-	if ( isset($tree) )
-	{
-		$level = 1;
-		$elements = _parseTreeToQuery( $tree, $level );
-		// Merge duplicate bracketing elements
-		for ( $i = 0; $i < count($elements); $i++ )
-		{
-			if ( $i > 0 && $elements[$i]['name'] == $elements[$i-1]['name'] )
-			{
-				$elements[$i-1]['value'] += $elements[$i]['value'];
-				array_splice( $elements, $i--, 1 );
-			}
-		}
-		$query = "trms=".$level;
-		foreach ( $elements as $element )
-		{
-			$query .= '&'.$element['name'].'='.$element['value'];
-		}
-	}
-	return( $query );
+    $filter = parseTreeToFilter( $tree );
+    parseFilter( $filter );
+	return( $filter['query'] );
 }
 
 function _drawTree( $node, $level )
