@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web zone view file, $Date: 2006/05/08 12:56:43 $, $Revision: 1.29 $
+// ZoneMinder web zone view file, $Date: 2007-09-17 23:07:50 +0100 (Mon, 17 Sep 2007) $, $Revision: 2207 $
 // Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -38,24 +38,17 @@ $marker = array(
 	"height"=>7,
 );
 
-$result = mysql_query( "select *, Units-1 as UnitsIndex, CheckMethod-1 as CheckMethodIndex from ZonePresets order by Id asc" );
-if ( !$result )
-	die( mysql_error() );
+$sql = "select *, Units-1 as UnitsIndex, CheckMethod-1 as CheckMethodIndex from ZonePresets order by Id asc";
 $presets = array();
 $preset_names = array();
 $preset_names[0] = $zmSlangChoosePreset;
-while ( $preset = mysql_fetch_assoc( $result ) )
+foreach( dbFetchAll( $sql ) as $preset )
 {
 	$preset_names[$preset['Id']] = $preset['Name'];
 	$presets[] = $preset;
 }
-mysql_free_result( $result );
 
-$result = mysql_query( "select * from Monitors where Id = '$mid'" );
-if ( !$result )
-	die( mysql_error() );
-$monitor = mysql_fetch_assoc( $result );
-mysql_free_result( $result );
+$monitor = dbFetchMonitor ( $mid );
 
 $min_x = 0;
 $max_x = $monitor['Width']-1;
@@ -66,11 +59,7 @@ if ( !isset($new_zone) )
 {
 	if ( $zid > 0 )
 	{
-		$result = mysql_query( "select * from Zones where MonitorId = '$mid' and Id = '$zid'" );
-		if ( !$result )
-			die( mysql_error() );
-		$zone = mysql_fetch_assoc( $result );
-		mysql_free_result( $result );
+		$zone = dbFetchOne( "select * from Zones where MonitorId = '$mid' and Id = '$zid'" );
 	}
 	else
 	{
@@ -162,6 +151,16 @@ var self_intersecting = <?= $self_intersecting?'true':'false' ?>;
 
 function validateForm()
 {
+<?php
+    if ( !canEdit( 'Monitors' ) )
+    {
+?>
+    return( false );
+<?php
+    }
+    else
+    {
+?>
 	var form = document.zone_form;
 	var errors = new Array();
 
@@ -244,6 +243,9 @@ function validateForm()
 		return( false );
 	}
 	return( true );
+<?php
+    }
+?>
 }
 
 function submitForm()
@@ -277,6 +279,7 @@ function applyZoneType()
 		form.elements['new_zone[MaxBlobPixels]'].disabled = true;
 		form.elements['new_zone[MinBlobs]'].disabled = true;
 		form.elements['new_zone[MaxBlobs]'].disabled = true;
+		form.elements['new_zone[OverloadFrames]'].disabled = true;
 	}
 	else if ( form.elements['new_zone[Type]'].value == 'Preclusive' )
 	{
@@ -289,6 +292,7 @@ function applyZoneType()
 		form.elements['new_zone[MaxPixelThreshold]'].disabled = false;
 		form.elements['new_zone[MinAlarmPixels]'].disabled = false;
 		form.elements['new_zone[MaxAlarmPixels]'].disabled = false;
+		form.elements['new_zone[OverloadFrames]'].disabled = false;
 		applyCheckMethod();
 	}
 	else
@@ -302,6 +306,7 @@ function applyZoneType()
 		form.elements['new_zone[MaxPixelThreshold]'].disabled = false;
 		form.elements['new_zone[MinAlarmPixels]'].disabled = false;
 		form.elements['new_zone[MaxAlarmPixels]'].disabled = false;
+		form.elements['new_zone[OverloadFrames]'].disabled = false;
 		applyCheckMethod(); 
 	}
 }
@@ -309,6 +314,10 @@ function applyZoneType()
 function applyCheckMethod()
 {
 	var form = document.zone_form;
+<?php
+    if ( canEdit('Monitors') )
+    {
+?>
 	if ( form.elements['new_zone[CheckMethod]'].value == 'AlarmedPixels' )
 	{
 		form.elements['new_zone[FilterX]'].disabled = true;
@@ -342,6 +351,35 @@ function applyCheckMethod()
 		form.elements['new_zone[MinBlobs]'].disabled = false;
 		form.elements['new_zone[MaxBlobs]'].disabled = false;
 	}
+<?php
+    }
+    else
+    {
+?>
+    form.elements['new_zone[Name]'].disabled = true;
+    form.elements['new_zone[Type]'].disabled = true;
+    form.presetSelector.disabled = true;
+    form.elements['new_zone[Units]'].disabled = true;
+    form.new_alarm_rgb_r.disabled = true;
+    form.new_alarm_rgb_g.disabled = true;
+    form.new_alarm_rgb_b.disabled = true;
+    form.elements['new_zone[CheckMethod]'].disabled = true;
+    form.elements['new_zone[MinPixelThreshold]'].disabled = true;
+    form.elements['new_zone[MaxPixelThreshold]'].disabled = true;
+    form.elements['new_zone[MinAlarmPixels]'].disabled = true;
+    form.elements['new_zone[MaxAlarmPixels]'].disabled = true;
+    form.elements['new_zone[FilterX]'].disabled = true;
+    form.elements['new_zone[FilterY]'].disabled = true;
+    form.elements['new_zone[MinFilterPixels]'].disabled = true;
+    form.elements['new_zone[MaxFilterPixels]'].disabled = true;
+    form.elements['new_zone[MinBlobPixels]'].disabled = true;
+    form.elements['new_zone[MaxBlobPixels]'].disabled = true;
+    form.elements['new_zone[MinBlobs]'].disabled = true;
+    form.elements['new_zone[MaxBlobs]'].disabled = true;
+    form.elements['new_zone[OverloadFrames]'].disabled = true;
+<?php
+	}
+?>
 }
 
 function applyPreset()
@@ -371,6 +409,7 @@ foreach ( $presets as $preset )
 			form.elements['new_zone[MaxBlobPixels]'].value = '<?= $preset['MaxBlobPixels'] ?>';
 			form.elements['new_zone[MinBlobs]'].value = '<?= $preset['MinBlobs'] ?>';
 			form.elements['new_zone[MaxBlobs]'].value = '<?= $preset['MaxBlobs'] ?>';
+			form.elements['new_zone[OverloadFrames]'].value = '<?= $preset['OverloadFrames'] ?>';
 			break;
 		}
 <?php
@@ -491,13 +530,19 @@ function highlightOff( index )
 
 function setActivePoint( index )
 {
+<?php
+    if ( canEdit( 'Monitors' ) )
+    {
+?>
+	var form = document.zone_form;
+	var errors = new Array();
 	if ( active >= 0 )
 	{
 		var last_active = active;
 		active = -1;
 		highlightOff( last_active );
 		if ( document.getElementById( 'delete'+last_active ) )
-			document.getElementById( 'delete'+last_active ).innerHTML="&ndash;";
+			document.getElementById( 'delete'+last_active ).innerHTML="";
 		document.getElementById( 'cancel'+last_active ).innerHTML="";
 	}
 	setBgColor( 'row'+index, '#FFA07A' );
@@ -510,10 +555,17 @@ function setActivePoint( index )
 	active = index;
 	document.getElementById( 'zoneImage' ).onclick = fixActivePoint;
 	document.getElementById( 'zoneImage' ).onmousemove = updateActivePoint;
+<?php
+    }
+?>
 }
 
 function unsetActivePoint( index )
 {
+<?php
+    if ( canEdit( 'Monitors' ) )
+    {
+?>
 	if ( active >= 0 )
 	{
 		var last_active = active;
@@ -531,19 +583,33 @@ function unsetActivePoint( index )
 			//document.getElementById( 'new_zone[Points]['+i+'][y]' ).disabled = true;
 		}
 	}
+<?php
+    }
+?>
 }
 
 function fixActivePoint( event )
 {
+<?php
+    if ( canEdit( 'Monitors' ) )
+    {
+?>
 	if ( active < 0 )
 		return;
 	
 	updateActivePoint( event );
 	submitForm();
+<?php
+    }
+?>
 }
 
 function updateActivePoint( event )
 {
+<?php
+    if ( canEdit( 'Monitors' ) )
+    {
+?>
 	var x, y;
 	var x_point, y_point;
 	if ( event )
@@ -562,30 +628,54 @@ function updateActivePoint( event )
 	y_point = document.getElementById( 'new_zone[Points]['+active+'][y]' );
 	x_point.value = x;
 	y_point.value = y;
+<?php
+    }
+?>
 }
 
 function addPoint( index )
 {
+<?php
+    if ( canEdit( 'Monitors' ) )
+    {
+?>
 	document.zone_form.action.value = "loc_addpoint";
 	document.zone_form.subaction.value = index;
 	submitForm();
+<?php
+    }
+?>
 }
 
 function delPoint( index )
 {
+<?php
+    if ( canEdit( 'Monitors' ) )
+    {
+?>
 	document.zone_form.action.value = "loc_delpoint";
 	document.zone_form.subaction.value = index;
 	submitForm();
+<?php
+    }
+?>
 }
 
 function updatePoint( point, lo_val, hi_val )
 {
+<?php
+    if ( canEdit( 'Monitors' ) )
+    {
+?>
 	if ( point.value < lo_val )
 		point.value = 0;
 	else if ( point.value > hi_val )
 		point.value = hi_val;
 	updateValues();
 	//document.zone_form.update_btn.disabled = false;
+<?php
+    }
+?>
 }
 
 function updateX( index )
@@ -600,18 +690,32 @@ function updateY( index )
 
 function updateValues()
 {
+<?php
+    if ( canEdit( 'Monitors' ) )
+    {
+?>
 	document.zone_form.action.value = '';
 	submitForm();
+<?php
+    }
+?>
 }
 
 function saveChanges()
 {
+<?php
+    if ( canEdit( 'Monitors' ) )
+    {
+?>
 	if ( validateForm() )
 	{
 		document.zone_form.action.value = 'zone';
 		submitForm();
 		return( true );
 	}
+<?php
+    }
+?>
 	return( false );
 }
 </script>
@@ -683,6 +787,8 @@ foreach ( getEnumValues( 'Zones', 'CheckMethod' ) as $opt_check_method )
 <tr><td align="left" class="text"><?= $zmSlangZoneMinMaxBlobArea ?></td><td align="left" class="text"><input type="text" name="new_zone[MinBlobPixels]" value="<?= $new_zone['MinBlobPixels'] ?>" size="6" class="form"></td><td align="left" class="text"><input type="text" name="new_zone[MaxBlobPixels]" value="<?= $new_zone['MaxBlobPixels'] ?>" size="6" class="form"></td></tr>
 <tr><td colspan="3"><img src="graphics/spacer.gif" width="1" height="5"></td></tr>
 <tr><td align="left" class="text"><?= $zmSlangZoneMinMaxBlobs ?></td><td align="left" class="text"><input type="text" name="new_zone[MinBlobs]" value="<?= $new_zone['MinBlobs'] ?>" size="4" class="form"></td><td align="left" class="text"><input type="text" name="new_zone[MaxBlobs]" value="<?= $new_zone['MaxBlobs'] ?>" size="4" class="form"></td></tr>
+<tr><td colspan="3"><img src="graphics/spacer.gif" width="1" height="5"></td></tr>
+<tr><td align="left" class="text"><?= $zmSlangZoneOverloadFrames ?></td><td colspan="2" align="left" class="text"><input type="text" name="new_zone[OverloadFrames]" value="<?= $new_zone['OverloadFrames'] ?>" size="4" class="form"></td></tr>
 <tr><td colspan="3" align="left" class="text">&nbsp;</td></tr>
 </table>
 </td>
@@ -722,8 +828,8 @@ for ( $i = 0; $i < $point_cols; $i++ )
 ?>
 <tr id="row<?= $j ?>" onMouseOver="highlightOn( <?= $j ?> )" onMouseOut="highlightOff( <?= $j ?> )" onClick="setActivePoint( <?= $j ?> )">
 <td align="center" class="text"><?= $j+1 ?></td>
-<td align="center" class="text"><input name="new_zone[Points][<?= $j ?>][x]" id="new_zone[Points][<?= $j ?>][x]" size="5" value="<?= $new_zone['Points'][$j]['x'] ?>" onChange="updateX( <?= $j ?> )" class="form"></td>
-<td align="center" class="text"><input name="new_zone[Points][<?= $j ?>][y]" id="new_zone[Points][<?= $j ?>][y]" size="5" value="<?= $new_zone['Points'][$j]['y'] ?>" onChange="updateY( <?= $j ?> )" class="form"></td>
+<td align="center" class="text"><input name="new_zone[Points][<?= $j ?>][x]" id="new_zone[Points][<?= $j ?>][x]" size="5" value="<?= $new_zone['Points'][$j]['x'] ?>" onChange="updateX( <?= $j ?> )" class="form"<?= canEdit( 'Monitors' )?"":" disabled" ?>></td>
+<td align="center" class="text"><input name="new_zone[Points][<?= $j ?>][y]" id="new_zone[Points][<?= $j ?>][y]" size="5" value="<?= $new_zone['Points'][$j]['y'] ?>" onChange="updateY( <?= $j ?> )" class="form"<?= canEdit( 'Monitors' )?"":" disabled" ?>></td>
 <td align="center" class="text"><a href="javascript: addPoint( <?= $j ?> );">+</a><?php if ( count($new_zone['Points']) > 3 ) { ?>&nbsp;<a id="delete<?= $j ?>" href="javascript: delPoint( <?= $j ?> )"></a><?php } ?>&nbsp;<a id="cancel<?= $j ?>" href="javascript: unsetActivePoint( <?= $j ?> )"></a></td>
 </tr>
 <?php
@@ -748,7 +854,7 @@ for ( $i = 0; $i < $point_cols; $i++ )
 <tr>
 <td align="left" width="40%">&nbsp;</td>
 <td align="center" width="20%"><!--<input type="button" name="update_btn" value="<?= $zmSlangUpdate ?>" class="form" onClick="updateValues()" disabled>--></td>
-<td align="right" width="40%"><input type="submit" value="<?= $zmSlangSave ?>" onClick="return saveChanges()" class="form"<?= false && $self_intersecting?" disabled":"" ?>>&nbsp;<input type="button" value="<?= $zmSlangCancel ?>" class="form" onClick="closeWindow()"></td>
+<td align="right" width="40%"><input type="submit" value="<?= $zmSlangSave ?>" onClick="return saveChanges()" class="form"<?= (!canEdit( 'Monitors' ) || (false && $self_intersecting))?" disabled":"" ?>>&nbsp;<input type="button" value="<?= $zmSlangCancel ?>" class="form" onClick="closeWindow()"></td>
 </tr>
 </table>
 </body>
