@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web Danish language file, $Date: 2006/11/29 15:46:38 $, $Revision: 1.19 $
+// ZoneMinder web Danish language file, $Date: 2008-01-08 12:33:11 +0000 (Tue, 08 Jan 2008) $, $Revision: 2281 $
 // Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -113,6 +113,7 @@ $zmSlangAttrMonitorId        = 'Monitor Id';
 $zmSlangAttrMonitorName      = 'Monitor Navn';
 $zmSlangAttrName             = 'Navn';
 $zmSlangAttrNotes            = 'Notes';
+$zmSlangAttrSystemLoad       = 'System Load';
 $zmSlangAttrTime             = 'Tid';
 $zmSlangAttrTotalScore       = 'Total Skore';
 $zmSlangAttrWeekday          = 'Uge Dag';
@@ -137,10 +138,12 @@ $zmSlangBadMaxFPS            = 'Maximum FPS must be a positive integer or floati
 $zmSlangBadNameChars         = 'Navne m kun indeholde alphanumeric karaktere plus hyphen og underscore';
 $zmSlangBadPath              = 'Path must be set to a valid value';
 $zmSlangBadPort              = 'Port must be set to a valid number';
-$zmSlangBadPostEventCount    = 'Post event image buffer must be an integer of zero or more';
-$zmSlangBadPreEventCount     = 'Pre event image buffer must be at least zero, and less than image buffer size';
-$zmSlangBadRefBlendPerc      = 'Reference blendpercentage must be a positive integer';
+$zmSlangBadPostEventCount    = 'Post event image count must be an integer of zero or more';
+$zmSlangBadPreEventCount     = 'Pre event image count must be at least zero, and less than image buffer size';
+$zmSlangBadRefBlendPerc      = 'Reference blend percentage must be a positive integer';
 $zmSlangBadSectionLength     = 'Section length must be an integer of 30 or more';
+$zmSlangBadSignalCheckColour = 'Signal check colour must be a valid RGB colour string';
+$zmSlangBadStreamReplayBuffer= 'Stream replay buffer must be an integer of zero or more';
 $zmSlangBadWarmupCount       = 'Warmup frames must be an integer of zero or more';
 $zmSlangBadWebColour         = 'Web colour must be a valid web colour string';
 $zmSlangBadWidth             = 'Width must be set to a valid value';
@@ -155,7 +158,7 @@ $zmSlangCanAutoGain          = 'Kan Auto Gain';
 $zmSlangCanAutoIris          = 'Kan Auto Iris';
 $zmSlangCanAutoWhite         = 'Kan Auto White Bal.';
 $zmSlangCanAutoZoom          = 'Kan Auto Zoom';
-$zmSlangCancelForcedAlarm    = 'Fortryd&nbsp;Forced&nbsp;Alarm';
+$zmSlangCancelForcedAlarm    = 'Fortryd Forced Alarm';
 $zmSlangCancel               = 'Fortryd';
 $zmSlangCanFocusAbs          = 'Kan Focus Absolut';
 $zmSlangCanFocusCon          = 'Kan Focus Kontinuerligt';
@@ -278,6 +281,7 @@ $zmSlangExportMiscFiles      = 'Export Other Files (if present)';
 $zmSlangExportOptions        = 'Export Options';
 $zmSlangExportVideoFiles     = 'Export Video Files (if present)';
 $zmSlangFar                  = 'Far';
+$zmSlangFastForward          = 'Fast Forward';
 $zmSlangFeed                 = 'Feed';
 $zmSlangFileColours          = 'File Colours';
 $zmSlangFile                 = 'File';
@@ -296,7 +300,7 @@ $zmSlangFirst                = 'Frste';
 $zmSlangFlippedHori          = 'Flipped Horizontally';
 $zmSlangFlippedVert          = 'Flipped Vertically';
 $zmSlangFocus                = 'Fokus';
-$zmSlangForceAlarm           = 'Tving&nbsp;Alarm';
+$zmSlangForceAlarm           = 'Tving Alarm';
 $zmSlangFormat               = 'Format';
 $zmSlangFPS                  = 'fps';
 $zmSlangFPSReportInterval    = 'FPS Raport Interval';
@@ -486,18 +490,22 @@ $zmSlangParameter            = 'Parameter';
 $zmSlangPassword             = 'Password';
 $zmSlangPasswordsDifferent   = 'Det nye og konfimerede passwords er forskellige';
 $zmSlangPaths                = 'Stiger';
+$zmSlangPause                = 'Pause';
 $zmSlangPhoneBW              = 'Telefon&nbsp;B/B';
 $zmSlangPhone                = 'Telefon';
 $zmSlangPixelDiff            = 'Pixel Diff';
 $zmSlangPixels               = 'pixels';
 $zmSlangPlayAll              = 'Afspil Alle';
+$zmSlangPlay                 = 'Play';
 $zmSlangPleaseWait           = 'Vent venligst';
 $zmSlangPoint                = 'Point';
 $zmSlangPostEventImageBuffer = 'Efter Event Billed Buffer';
 $zmSlangPreEventImageBuffer  = 'Fr Event Billed Buffer';
+$zmSlangPreserveAspect       = 'Preserve Aspect Ratio';
 $zmSlangPreset               = 'Preset';
 $zmSlangPresets              = 'Presets';
 $zmSlangPrev                 = 'Prev';
+$zmSlangProtocol             = 'Protocol';
 $zmSlangRate                 = 'Rate';
 $zmSlangReal                 = 'Real';
 $zmSlangRecord               = 'Optag';
@@ -509,6 +517,10 @@ $zmSlangRemoteHostPort       = 'Remote Host Port';
 $zmSlangRemoteImageColours   = 'Remote Image Farver';
 $zmSlangRemote               = 'Remote';
 $zmSlangRename               = 'Omdb';
+$zmSlangReplayAll            = 'All Events';
+$zmSlangReplayGapless        = 'Gapless Events';
+$zmSlangReplay               = 'Replay';
+$zmSlangReplaySingle         = 'Single Event';
 $zmSlangReplay               = 'Spil Igen';
 $zmSlangResetEventCounts     = 'Reset Event Counts';
 $zmSlangReset                = 'Nulstil';
@@ -518,6 +530,7 @@ $zmSlangRestrictedCameraIds  = 'Begranset Kamera Ids';
 $zmSlangRestrictedMonitors   = 'Restricted Monitors';
 $zmSlangReturnDelay          = 'Return Delay';
 $zmSlangReturnLocation       = 'Return Location';
+$zmSlangRewind               = 'Rewind';
 $zmSlangRotateLeft           = 'Rotate Left';
 $zmSlangRotateRight          = 'Rotate Right';
 $zmSlangRunMode              = 'Krsels Mode';
@@ -540,6 +553,7 @@ $zmSlangSet                  = 'St';
 $zmSlangSettings             = 'Indstillinger';
 $zmSlangShowFilterWindow     = 'VisFilterVindue';
 $zmSlangShowTimeline         = 'Show Timeline';
+$zmSlangSignalCheckColour    = 'Signal Check Colour';
 $zmSlangSize                 = 'Size';
 $zmSlangSleep                = 'Sov';
 $zmSlangSortAsc              = 'Asc';
@@ -556,6 +570,8 @@ $zmSlangStart                = 'Start';
 $zmSlangState                = 'State';
 $zmSlangStats                = 'Stats';
 $zmSlangStatus               = 'Status';
+$zmSlangStepBack             = 'Step Back';
+$zmSlangStepForward          = 'Step Forward';
 $zmSlangStepLarge            = 'Large Step';
 $zmSlangStepMedium           = 'Medium Step';
 $zmSlangStepNone             = 'No Step';
@@ -564,6 +580,7 @@ $zmSlangStep                 = 'Step';
 $zmSlangStills               = 'Stills';
 $zmSlangStopped              = 'Stoppet';
 $zmSlangStop                 = 'Stop';
+$zmSlangStreamReplayBuffer   = 'Stream Replay Image Buffer';
 $zmSlangStream               = 'Stream';
 $zmSlangSubmit               = 'Submit';
 $zmSlangSystem               = 'System';
@@ -643,6 +660,7 @@ $zmSlangZoneMinMaxBlobArea   = 'Min/Max Blob Area';
 $zmSlangZoneMinMaxBlobs      = 'Min/Max Blobs';
 $zmSlangZoneMinMaxFiltArea   = 'Min/Max Filtered Area';
 $zmSlangZoneMinMaxPixelThres = 'Min/Max Pixel Threshold (0-255)';
+$zmSlangZoneOverloadFrames   = 'Overload Frame Ignore Count';
 $zmSlangZones                = 'Zoner';
 $zmSlangZone                 = 'Zone';
 $zmSlangZoomIn               = 'Zoom In';
