@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web UK English language file, $Date: 2006/11/29 15:46:38 $, $Revision: 1.85 $
+// ZoneMinder web UK English language file, $Date: 2008-01-08 12:33:11 +0000 (Tue, 08 Jan 2008) $, $Revision: 2281 $
 // Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -112,6 +112,7 @@ $zmSlangAttrMonitorId        = 'Monitor Id';
 $zmSlangAttrMonitorName      = 'Monitor Name';
 $zmSlangAttrName             = 'Name';
 $zmSlangAttrNotes            = 'Notes';
+$zmSlangAttrSystemLoad       = 'System Load';
 $zmSlangAttrTime             = 'Time';
 $zmSlangAttrTotalScore       = 'Total Score';
 $zmSlangAttrWeekday          = 'Weekday';
@@ -136,10 +137,12 @@ $zmSlangBadMaxFPS            = 'Maximum FPS must be a positive integer or floati
 $zmSlangBadNameChars         = 'Names may only contain alphanumeric characters plus hyphen and underscore';
 $zmSlangBadPath              = 'Path must be set to a valid value';
 $zmSlangBadPort              = 'Port must be set to a valid number';
-$zmSlangBadPostEventCount    = 'Post event image buffer must be an integer of zero or more';
-$zmSlangBadPreEventCount     = 'Pre event image buffer must be at least zero, and less than image buffer size';
-$zmSlangBadRefBlendPerc      = 'Reference blendpercentage must be a positive integer';
+$zmSlangBadPostEventCount    = 'Post event image count must be an integer of zero or more';
+$zmSlangBadPreEventCount     = 'Pre event image count must be at least zero, and less than image buffer size';
+$zmSlangBadRefBlendPerc      = 'Reference blend percentage must be a positive integer';
 $zmSlangBadSectionLength     = 'Section length must be an integer of 30 or more';
+$zmSlangBadSignalCheckColour = 'Signal check colour must be a valid RGB colour string';
+$zmSlangBadStreamReplayBuffer= 'Stream replay buffer must be an integer of zero or more';
 $zmSlangBadWarmupCount       = 'Warmup frames must be an integer of zero or more';
 $zmSlangBadWebColour         = 'Web colour must be a valid web colour string';
 $zmSlangBadWidth             = 'Width must be set to a valid value';
@@ -155,7 +158,7 @@ $zmSlangCanAutoIris          = 'Can Auto Iris';
 $zmSlangCanAutoWhite         = 'Can Auto White Bal.';
 $zmSlangCanAutoZoom          = 'Can Auto Zoom';
 $zmSlangCancel               = 'Cancel';
-$zmSlangCancelForcedAlarm    = 'Cancel&nbsp;Forced&nbsp;Alarm';
+$zmSlangCancelForcedAlarm    = 'Cancel Forced Alarm';
 $zmSlangCanFocusAbs          = 'Can Focus Absolute';
 $zmSlangCanFocus             = 'Can Focus';
 $zmSlangCanFocusCon          = 'Can Focus Continuous';
@@ -277,6 +280,7 @@ $zmSlangExportMiscFiles      = 'Export Other Files (if present)';
 $zmSlangExportOptions        = 'Export Options';
 $zmSlangExportVideoFiles     = 'Export Video Files (if present)';
 $zmSlangFar                  = 'Far';
+$zmSlangFastForward          = 'Fast Forward';
 $zmSlangFeed                 = 'Feed';
 $zmSlangFileColours          = 'File Colours';
 $zmSlangFile                 = 'File';
@@ -295,7 +299,7 @@ $zmSlangFirst                = 'First';
 $zmSlangFlippedHori          = 'Flipped Horizontally';
 $zmSlangFlippedVert          = 'Flipped Vertically';
 $zmSlangFocus                = 'Focus';
-$zmSlangForceAlarm           = 'Force&nbsp;Alarm';
+$zmSlangForceAlarm           = 'Force Alarm';
 $zmSlangFormat               = 'Format';
 $zmSlangFPS                  = 'fps';
 $zmSlangFPSReportInterval    = 'FPS Report Interval';
@@ -485,18 +489,22 @@ $zmSlangParameter            = 'Parameter';
 $zmSlangPassword             = 'Password';
 $zmSlangPasswordsDifferent   = 'The new and confirm passwords are different';
 $zmSlangPaths                = 'Paths';
+$zmSlangPause                = 'Pause';
 $zmSlangPhoneBW              = 'Phone&nbsp;B/W';
 $zmSlangPhone                = 'Phone';
 $zmSlangPixelDiff            = 'Pixel Diff';
 $zmSlangPixels               = 'pixels';
 $zmSlangPlayAll              = 'Play All';
+$zmSlangPlay                 = 'Play';
 $zmSlangPleaseWait           = 'Please Wait';
 $zmSlangPoint                = 'Point';
-$zmSlangPostEventImageBuffer = 'Post Event Image Buffer';
-$zmSlangPreEventImageBuffer  = 'Pre Event Image Buffer';
+$zmSlangPostEventImageBuffer = 'Post Event Image Count';
+$zmSlangPreEventImageBuffer  = 'Pre Event Image Count';
+$zmSlangPreserveAspect       = 'Preserve Aspect Ratio';
 $zmSlangPreset               = 'Preset';
 $zmSlangPresets              = 'Presets';
 $zmSlangPrev                 = 'Prev';
+$zmSlangProtocol             = 'Protocol';
 $zmSlangRate                 = 'Rate';
 $zmSlangReal                 = 'Real';
 $zmSlangRecord               = 'Record';
@@ -508,7 +516,10 @@ $zmSlangRemoteHostPort       = 'Remote Host Port';
 $zmSlangRemoteImageColours   = 'Remote Image Colours';
 $zmSlangRemote               = 'Remote';
 $zmSlangRename               = 'Rename';
+$zmSlangReplayAll            = 'All Events';
+$zmSlangReplayGapless        = 'Gapless Events';
 $zmSlangReplay               = 'Replay';
+$zmSlangReplaySingle         = 'Single Event';
 $zmSlangResetEventCounts     = 'Reset Event Counts';
 $zmSlangReset                = 'Reset';
 $zmSlangRestarting           = 'Restarting';
@@ -517,6 +528,7 @@ $zmSlangRestrictedCameraIds  = 'Restricted Camera Ids';
 $zmSlangRestrictedMonitors   = 'Restricted Monitors';
 $zmSlangReturnDelay          = 'Return Delay';
 $zmSlangReturnLocation       = 'Return Location';
+$zmSlangRewind               = 'Rewind';
 $zmSlangRotateLeft           = 'Rotate Left';
 $zmSlangRotateRight          = 'Rotate Right';
 $zmSlangRunMode              = 'Run Mode';
@@ -539,6 +551,7 @@ $zmSlangSet                  = 'Set';
 $zmSlangSettings             = 'Settings';
 $zmSlangShowFilterWindow     = 'Show Filter Window';
 $zmSlangShowTimeline         = 'Show Timeline';
+$zmSlangSignalCheckColour    = 'Signal Check Colour';
 $zmSlangSize                 = 'Size';
 $zmSlangSleep                = 'Sleep';
 $zmSlangSortAsc              = 'Asc';
@@ -555,6 +568,8 @@ $zmSlangStart                = 'Start';
 $zmSlangState                = 'State';
 $zmSlangStats                = 'Stats';
 $zmSlangStatus               = 'Status';
+$zmSlangStepBack             = 'Step Back';
+$zmSlangStepForward          = 'Step Forward';
 $zmSlangStepLarge            = 'Large Step';
 $zmSlangStepMedium           = 'Medium Step';
 $zmSlangStepNone             = 'No Step';
@@ -563,6 +578,7 @@ $zmSlangStep                 = 'Step';
 $zmSlangStills               = 'Stills';
 $zmSlangStopped              = 'Stopped';
 $zmSlangStop                 = 'Stop';
+$zmSlangStreamReplayBuffer   = 'Stream Replay Image Buffer';
 $zmSlangStream               = 'Stream';
 $zmSlangSubmit               = 'Submit';
 $zmSlangSystem               = 'System';
@@ -642,6 +658,7 @@ $zmSlangZoneMinMaxBlobArea   = 'Min/Max Blob Area';
 $zmSlangZoneMinMaxBlobs      = 'Min/Max Blobs';
 $zmSlangZoneMinMaxFiltArea   = 'Min/Max Filtered Area';
 $zmSlangZoneMinMaxPixelThres = 'Min/Max Pixel Threshold (0-255)';
+$zmSlangZoneOverloadFrames   = 'Overload Frame Ignore Count';
 $zmSlangZones                = 'Zones';
 $zmSlangZone                 = 'Zone';
 $zmSlangZoomIn               = 'Zoom In';
