@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web Argentinian Spanish language file, $Date: 2006/11/29 15:46:38 $, $Revision: 1.24 $
+// ZoneMinder web Argentinian Spanish language file, $Date: 2008-01-08 12:33:11 +0000 (Tue, 08 Jan 2008) $, $Revision: 2281 $
 // Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -64,6 +64,7 @@ $zmSlangAttrMonitorName      = 'Nombre Monitor';
 $zmSlangAttrMontage          = 'Cmara Mltiple';
 $zmSlangAttrName             = 'Name';
 $zmSlangAttrNotes            = 'Notes';
+$zmSlangAttrSystemLoad       = 'System Load';
 $zmSlangAttrTime             = 'Hora';
 $zmSlangAttrTotalScore       = 'Puntaje Total';
 $zmSlangAttrWeekday          = 'Da Semana';
@@ -88,10 +89,12 @@ $zmSlangBadMaxFPS            = 'Maximum FPS must be a positive integer or floati
 $zmSlangBadNameChars         = 'Los nombres pueden contener solamente caracteres alfanumricos ms el guin y la raya';
 $zmSlangBadPath              = 'Path must be set to a valid value';
 $zmSlangBadPort              = 'Port must be set to a valid number';
-$zmSlangBadPostEventCount    = 'Post event image buffer must be an integer of zero or more';
-$zmSlangBadPreEventCount     = 'Pre event image buffer must be at least zero, and less than image buffer size';
-$zmSlangBadRefBlendPerc      = 'Reference blendpercentage must be a positive integer';
+$zmSlangBadPostEventCount    = 'Post event image count must be an integer of zero or more';
+$zmSlangBadPreEventCount     = 'Pre event image count must be at least zero, and less than image buffer size';
+$zmSlangBadRefBlendPerc      = 'Reference blend percentage must be a positive integer';
 $zmSlangBadSectionLength     = 'Section length must be an integer of 30 or more';
+$zmSlangBadSignalCheckColour = 'Signal check colour must be a valid RGB colour string';
+$zmSlangBadStreamReplayBuffer= 'Stream replay buffer must be an integer of zero or more';
 $zmSlangBadWarmupCount       = 'Warmup frames must be an integer of zero or more';
 $zmSlangBadWebColour         = 'Web colour must be a valid web colour string';
 $zmSlangBadWidth             = 'Width must be set to a valid value';
@@ -107,7 +110,7 @@ $zmSlangCanAutoIris          = 'Can Auto Iris';
 $zmSlangCanAutoWhite         = 'Can Auto White Bal.';
 $zmSlangCanAutoZoom          = 'Can Auto Zoom';
 $zmSlangCancel               = 'Cancelar';
-$zmSlangCancelForcedAlarm    = 'Cancelar&nbsp;Alarma&nbsp;Forzada';
+$zmSlangCancelForcedAlarm    = 'Cancelar Alarma Forzada';
 $zmSlangCanFocusAbs          = 'Can Focus Absolute';
 $zmSlangCanFocus             = 'Can Focus';
 $zmSlangCanFocusCon          = 'Can Focus Continuous';
@@ -230,6 +233,7 @@ $zmSlangExportMiscFiles      = 'Export Other Files (if present)';
 $zmSlangExportOptions        = 'Export Options';
 $zmSlangExportVideoFiles     = 'Export Video Files (if present)';
 $zmSlangFar                  = 'Far';
+$zmSlangFastForward          = 'Fast Forward';
 $zmSlangFeed                 = 'Vista';
 $zmSlangFileColours          = 'File Colours';
 $zmSlangFile                 = 'File';
@@ -248,7 +252,7 @@ $zmSlangFirst                = 'Primero';
 $zmSlangFlippedHori          = 'Flipped Horizontally';
 $zmSlangFlippedVert          = 'Flipped Vertically';
 $zmSlangFocus                = 'Focus';
-$zmSlangForceAlarm           = 'Forzar&nbsp;Alarma';
+$zmSlangForceAlarm           = 'Forzar Alarma';
 $zmSlangFormat               = 'Format';
 $zmSlangFPS                  = 'fps';
 $zmSlangFPSReportInterval    = 'Intervalo de Reporte FPS';
@@ -439,17 +443,21 @@ $zmSlangParameter            = 'Parametro';
 $zmSlangPassword             = 'Contrasea';
 $zmSlangPasswordsDifferent   = 'Las contraseas nueva y de confirmacion son diferentes';
 $zmSlangPaths                = 'Enlaces';
+$zmSlangPause                = 'Pause';
 $zmSlangPhoneBW              = 'Tel.&nbsp;B/N';
 $zmSlangPhone                = 'Phone';
 $zmSlangPixels               = 'pixels';
 $zmSlangPlayAll              = 'Play All';
+$zmSlangPlay                 = 'Play';
 $zmSlangPleaseWait           = 'Espere por favor';
 $zmSlangPoint                = 'Point';
 $zmSlangPostEventImageBuffer = 'Buffer Imagenes despues evento';
 $zmSlangPreEventImageBuffer  = 'Buffer Imagenes antes evento';
+$zmSlangPreserveAspect       = 'Preserve Aspect Ratio';
 $zmSlangPreset               = 'Preset';
 $zmSlangPresets              = 'Presets';
 $zmSlangPrev                 = 'Prev';
+$zmSlangProtocol             = 'Protocol';
 $zmSlangRate                 = 'Ritmo';
 $zmSlangReal                 = 'Real';
 $zmSlangRecord               = 'Registro';
@@ -461,7 +469,10 @@ $zmSlangRemoteHostPort       = 'Puerto Servidor Remoto';
 $zmSlangRemoteImageColours   = 'Remote Image Colours';
 $zmSlangRemote               = 'Remote';
 $zmSlangRename               = 'Renombrar';
+$zmSlangReplayAll            = 'All Events';
+$zmSlangReplayGapless        = 'Gapless Events';
 $zmSlangReplay               = 'Replay';
+$zmSlangReplaySingle         = 'Single Event';
 $zmSlangResetEventCounts     = 'Borrar Contador Eventos';
 $zmSlangReset                = 'Reset';
 $zmSlangRestarting           = 'Reiniciando';
@@ -470,6 +481,7 @@ $zmSlangRestrictedCameraIds  = 'Id. Camara restringida';
 $zmSlangRestrictedMonitors   = 'Restricted Monitors';
 $zmSlangReturnDelay          = 'Return Delay';
 $zmSlangReturnLocation       = 'Return Location';
+$zmSlangRewind               = 'Rewind';
 $zmSlangRotateLeft           = 'Rotar a la derecha';
 $zmSlangRotateRight          = 'Rotar a la izquierda';
 $zmSlangRunMode              = 'Metodo Ejecucion';
@@ -493,6 +505,7 @@ $zmSlangSet                  = 'Set';
 $zmSlangSettings             = 'Configuracion';
 $zmSlangShowFilterWindow     = 'Abrir Filtro';
 $zmSlangShowTimeline         = 'Show Timeline';
+$zmSlangSignalCheckColour    = 'Signal Check Colour';
 $zmSlangSize                 = 'Size';
 $zmSlangSleep                = 'Sleep';
 $zmSlangSortAsc              = 'Asc';
@@ -509,6 +522,8 @@ $zmSlangStart                = 'Iniciar';
 $zmSlangState                = 'Estado';
 $zmSlangStats                = 'Est.';
 $zmSlangStatus               = 'Estado';
+$zmSlangStepBack             = 'Step Back';
+$zmSlangStepForward          = 'Step Forward';
 $zmSlangStepLarge            = 'Large Step';
 $zmSlangStepMedium           = 'Medium Step';
 $zmSlangStepNone             = 'No Step';
@@ -517,6 +532,7 @@ $zmSlangStep                 = 'Step';
 $zmSlangStills               = 'Fotos';
 $zmSlangStop                 = 'Desactivar';
 $zmSlangStopped              = 'Apagado';
+$zmSlangStreamReplayBuffer   = 'Stream Replay Image Buffer';
 $zmSlangStream               = 'Stream';
 $zmSlangSubmit               = 'Submit';
 $zmSlangSystem               = 'Sistema';
@@ -596,13 +612,13 @@ $zmSlangZoneMinMaxBlobArea   = 'Min/Max Blob Area';
 $zmSlangZoneMinMaxBlobs      = 'Min/Max Blobs';
 $zmSlangZoneMinMaxFiltArea   = 'Min/Max Filtered Area';
 $zmSlangZoneMinMaxPixelThres = 'Min/Max Pixel Threshold (0-255)';
+$zmSlangZoneOverloadFrames   = 'Overload Frame Ignore Count';
 $zmSlangZones                = 'Zonas';
 $zmSlangZone                 = 'Zona';
 $zmSlangZoomIn               = 'Zoom In';
 $zmSlangZoomOut              = 'Zoom Out';
 $zmSlangZoom                 = 'Zoom';
 
-
 // Complex replacements with formatting and/or placements, must be passed through sprintf
 $zmClangCurrentLogin         = 'Usuario actual es \'%1$s\'';
 $zmClangEventCount           = '%1$s %2$s';
