@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web Japanese language file, $Date: 2006/11/29 15:46:38 $, $Revision: 1.31 $
+// ZoneMinder web Japanese language file, $Date: 2008-01-08 12:33:11 +0000 (Tue, 08 Jan 2008) $, $Revision: 2281 $
 // Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -112,6 +112,7 @@ $zmSlangAttrMonitorId        = ' Id';
 $zmSlangAttrMonitorName      = ' O';
 $zmSlangAttrName             = 'Name';
 $zmSlangAttrNotes            = 'Notes';
+$zmSlangAttrSystemLoad       = 'System Load';
 $zmSlangAttrTime             = '';
 $zmSlangAttrTotalScore       = 'v';
 $zmSlangAttrWeekday          = 'j';
@@ -136,10 +137,12 @@ $zmSlangBadMaxFPS            = 'Maximum FPS must be a positive integer or floati
 $zmSlangBadNameChars         = 'Names may only contain alphanumeric characters plus hyphen and underscore';
 $zmSlangBadPath              = 'Path must be set to a valid value';
 $zmSlangBadPort              = 'Port must be set to a valid number';
-$zmSlangBadPostEventCount    = 'Post event image buffer must be an integer of zero or more';
-$zmSlangBadPreEventCount     = 'Pre event image buffer must be at least zero, and less than image buffer size';
-$zmSlangBadRefBlendPerc      = 'Reference blendpercentage must be a positive integer';
+$zmSlangBadPostEventCount    = 'Post event image count must be an integer of zero or more';
+$zmSlangBadPreEventCount     = 'Pre event image count must be at least zero, and less than image buffer size';
+$zmSlangBadRefBlendPerc      = 'Reference blend percentage must be a positive integer';
 $zmSlangBadSectionLength     = 'Section length must be an integer of 30 or more';
+$zmSlangBadSignalCheckColour = 'Signal check colour must be a valid RGB colour string';
+$zmSlangBadStreamReplayBuffer= 'Stream replay buffer must be an integer of zero or more';
 $zmSlangBadWarmupCount       = 'Warmup frames must be an integer of zero or more';
 $zmSlangBadWebColour         = 'Web colour must be a valid web colour string';
 $zmSlangBadWidth             = 'Width must be set to a valid value';
@@ -277,6 +280,7 @@ $zmSlangExportMiscFiles      = 'Export Other Files (if present)';
 $zmSlangExportOptions        = 'Export Options';
 $zmSlangExportVideoFiles     = 'Export Video Files (if present)';
 $zmSlangFar                  = 'Far';
+$zmSlangFastForward          = 'Fast Forward';
 $zmSlangFeed                 = '荞';
 $zmSlangFileColours          = 'File Colours';
 $zmSlangFile                 = 'File';
@@ -459,11 +463,11 @@ $zmSlangOff                  = 'Off';
 $zmSlangOn                   = 'On';
 $zmSlangOpen                 = 'Open';
 $zmSlangOpEq                 = '';
-$zmSlangOpGt                 = 'ȉ';
 $zmSlangOpGtEq               = 'ȏ';
+$zmSlangOpGt                 = 'ȉ';
 $zmSlangOpIn                 = 'ĂɓĂ';
-$zmSlangOpLt                 = 'ȉ';
 $zmSlangOpLtEq               = 'ȉ';
+$zmSlangOpLt                 = 'ȉ';
 $zmSlangOpMatches            = 'v';
 $zmSlangOpNe                 = 'łȂ';
 $zmSlangOpNotIn              = 'ĂɓĂȂ';
@@ -485,30 +489,38 @@ $zmSlangParameter            = 'Ұ';
 $zmSlangPassword             = '߽ܰ';
 $zmSlangPasswordsDifferent   = 'VpX[hƍē̓pX[hv܂';
 $zmSlangPaths                = '߽';
+$zmSlangPause                = 'Pause';
 $zmSlangPhoneBW              = 'gїp';
 $zmSlangPhone                = 'Phone';
 $zmSlangPixelDiff            = 'Pixel Diff';
 $zmSlangPixels               = '߸';
 $zmSlangPlayAll              = 'Play All';
+$zmSlangPlay                 = 'Play';
 $zmSlangPleaseWait           = '҂';
 $zmSlangPoint                = 'Point';
 $zmSlangPostEventImageBuffer = ' Ұ ޯ̧';
 $zmSlangPreEventImageBuffer  = ' Ұ ޯ̧O';
+$zmSlangPreserveAspect       = 'Preserve Aspect Ratio';
 $zmSlangPreset               = 'Preset';
 $zmSlangPresets              = 'Presets';
 $zmSlangPrev                 = 'O';
+$zmSlangProtocol             = 'Protocol';
 $zmSlangRate                 = 'ڰ';
 $zmSlangReal                 = 'p';
 $zmSlangRecord               = '^';
 $zmSlangRefImageBlendPct     = 'Ұ  Q %';
 $zmSlangRefresh              = 'ŐV̏ɍXV';
-$zmSlangRemote               = 'Ӱ';
 $zmSlangRemoteHostName       = 'Ӱ ν ';
 $zmSlangRemoteHostPath       = 'Ӱ ν ߽';
 $zmSlangRemoteHostPort       = 'Ӱ ν ߰';
 $zmSlangRemoteImageColours   = 'Ӱ Ұ װ';
+$zmSlangRemote               = 'Ӱ';
 $zmSlangRename               = 'VO';
+$zmSlangReplayAll            = 'All Events';
 $zmSlangReplay               = 'Đ';
+$zmSlangReplayGapless        = 'Gapless Events';
+$zmSlangReplay               = 'Replay';
+$zmSlangReplaySingle         = 'Single Event';
 $zmSlangResetEventCounts     = '  ؾ';
 $zmSlangReset                = 'Reset';
 $zmSlangRestart              = 'ċN';
@@ -517,6 +529,7 @@ $zmSlangRestrictedCameraIds  = 'ꂽ ID';
 $zmSlangRestrictedMonitors   = 'Restricted Monitors';
 $zmSlangReturnDelay          = 'Return Delay';
 $zmSlangReturnLocation       = 'Return Location';
+$zmSlangRewind               = 'Rewind';
 $zmSlangRotateLeft           = 'ɉ]';
 $zmSlangRotateRight          = 'Eɉ]';
 $zmSlangRunMode              = 'NӰ';
@@ -539,6 +552,7 @@ $zmSlangSet                  = 'Set';
 $zmSlangSettings             = 'ݒ';
 $zmSlangShowFilterWindow     = '̨ ް̕\';
 $zmSlangShowTimeline         = 'Show Timeline';
+$zmSlangSignalCheckColour    = 'Signal Check Colour';
 $zmSlangSize                 = 'Size';
 $zmSlangSleep                = 'Sleep';
 $zmSlangSortAsc              = 'Asc';
@@ -555,6 +569,8 @@ $zmSlangStart                = '';
 $zmSlangState                = '';
 $zmSlangStats                = 'v';
 $zmSlangStatus               = '';
+$zmSlangStepBack             = 'Step Back';
+$zmSlangStepForward          = 'Step Forward';
 $zmSlangStepLarge            = 'Large Step';
 $zmSlangStepMedium           = 'Medium Step';
 $zmSlangStepNone             = 'No Step';
@@ -563,6 +579,7 @@ $zmSlangStep                 = 'Step';
 $zmSlangStills               = 'ى摜';
 $zmSlangStop                 = '~';
 $zmSlangStopped              = '~';
+$zmSlangStreamReplayBuffer   = 'Stream Replay Image Buffer';
 $zmSlangStream               = 'ذ';
 $zmSlangSubmit               = 'Submit';
 $zmSlangSystem               = '';
@@ -595,9 +612,9 @@ $zmSlangUpdate               = 'Update';
 $zmSlangUseFilterExprsPost   = '&nbsp;̨'; // This is used at the end of the phrase 'use N filter expressions'
 $zmSlangUseFilterExprsPre    = 'w肵Ă:&nbsp;'; // This is used at the beginning of the phrase 'use N filter expressions'
 $zmSlangUseFilter            = '̨gpĂ';
-$zmSlangUser                 = 'հ';
 $zmSlangUsername             = 'հޖ';
 $zmSlangUsers                = 'հ';
+$zmSlangUser                 = 'հ';
 $zmSlangValue                = 'l';
 $zmSlangVersion              = 'ްޮ';
 $zmSlangVersionIgnore        = 'ްޮ݂𖳎';
@@ -643,12 +660,12 @@ $zmSlangZoneMinMaxBlobArea   = 'Min/Max Blob Area';
 $zmSlangZoneMinMaxBlobs      = 'Min/Max Blobs';
 $zmSlangZoneMinMaxFiltArea   = 'Min/Max Filtered Area';
 $zmSlangZoneMinMaxPixelThres = 'Min/Max Pixel Threshold (0-255)';
+$zmSlangZoneOverloadFrames   = 'Overload Frame Ignore Count';
 $zmSlangZones                = 'ް';
 $zmSlangZoomIn               = 'Zoom In';
 $zmSlangZoomOut              = 'Zoom Out';
 $zmSlangZoom                 = 'Zoom';
 
-
 // Complex replacements with formatting and/or placements, must be passed through sprintf
 $zmClangCurrentLogin         = '\'%1$s\۸޲݂Ă܂';
 $zmClangEventCount           = '%1$s %2$s';
