@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web Dutch language file, $Date: 2006/11/29 15:46:38 $, $Revision: 1.29 $
+// ZoneMinder web Dutch language file, $Date: 2008-01-08 12:33:11 +0000 (Tue, 08 Jan 2008) $, $Revision: 2281 $
 // Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -113,6 +113,7 @@ $zmSlangAttrMonitorName      = 'Monitor Naam';
 $zmSlangAttrMontage          = 'Montage';
 $zmSlangAttrName             = 'Name';
 $zmSlangAttrNotes            = 'Notes';
+$zmSlangAttrSystemLoad       = 'System Load';
 $zmSlangAttrTime             = 'Tijd';
 $zmSlangAttrTotalScore       = 'Totale Score';
 $zmSlangAttrWeekday          = 'Weekdag';
@@ -137,10 +138,12 @@ $zmSlangBadMaxFPS            = 'Maximum FPS must be a positive integer or floati
 $zmSlangBadNameChars         = 'Namen mogen alleen alpha numerieke karakters bevatten plus hyphens en underscores';
 $zmSlangBadPath              = 'Path must be set to a valid value';
 $zmSlangBadPort              = 'Port must be set to a valid number';
-$zmSlangBadPostEventCount    = 'Post event image buffer must be an integer of zero or more';
-$zmSlangBadPreEventCount     = 'Pre event image buffer must be at least zero, and less than image buffer size';
-$zmSlangBadRefBlendPerc      = 'Reference blendpercentage must be a positive integer';
+$zmSlangBadPostEventCount    = 'Post event image count must be an integer of zero or more';
+$zmSlangBadPreEventCount     = 'Pre event image count must be at least zero, and less than image buffer size';
+$zmSlangBadRefBlendPerc      = 'Reference blend percentage must be a positive integer';
 $zmSlangBadSectionLength     = 'Section length must be an integer of 30 or more';
+$zmSlangBadSignalCheckColour = 'Signal check colour must be a valid RGB colour string';
+$zmSlangBadStreamReplayBuffer= 'Stream replay buffer must be an integer of zero or more';
 $zmSlangBadWarmupCount       = 'Warmup frames must be an integer of zero or more';
 $zmSlangBadWebColour         = 'Web colour must be a valid web colour string';
 $zmSlangBadWidth             = 'Width must be set to a valid value';
@@ -156,7 +159,7 @@ $zmSlangCanAutoIris          = 'Can Auto Iris';
 $zmSlangCanAutoWhite         = 'Can Auto White Bal.';
 $zmSlangCanAutoZoom          = 'Can Auto Zoom';
 $zmSlangCancel               = 'Cancel';
-$zmSlangCancelForcedAlarm    = 'Cancel&nbsp;geforceerd&nbsp;alarm';
+$zmSlangCancelForcedAlarm    = 'Cancel geforceerd alarm';
 $zmSlangCanFocusAbs          = 'Can Focus Absolute';
 $zmSlangCanFocus             = 'Can Focus';
 $zmSlangCanFocusCon          = 'Can Focus Continuous';
@@ -278,6 +281,7 @@ $zmSlangExportMiscFiles      = 'Export Other Files (if present)';
 $zmSlangExportOptions        = 'Export Options';
 $zmSlangExportVideoFiles     = 'Export Video Files (if present)';
 $zmSlangFar                  = 'Far';
+$zmSlangFastForward          = 'Fast Forward';
 $zmSlangFeed                 = 'toevoer';
 $zmSlangFileColours          = 'File Colours';
 $zmSlangFile                 = 'File';
@@ -296,7 +300,7 @@ $zmSlangFirst                = 'Eerste';
 $zmSlangFlippedHori          = 'Flipped Horizontally';
 $zmSlangFlippedVert          = 'Flipped Vertically';
 $zmSlangFocus                = 'Focus';
-$zmSlangForceAlarm           = 'Forceeer&nbsp;alarm';
+$zmSlangForceAlarm           = 'Forceeer alarm';
 $zmSlangFormat               = 'Format';
 $zmSlangFPS                  = 'fps';
 $zmSlangFPSReportInterval    = 'FPS rapport interval';
@@ -486,18 +490,22 @@ $zmSlangParameter            = 'Parameter';
 $zmSlangPasswordsDifferent   = 'Het nieuwe en bevestigde wachtwoord zijn verschillend';
 $zmSlangPassword             = 'Wachtwoord';
 $zmSlangPaths                = 'Paden';
+$zmSlangPause                = 'Pause';
 $zmSlangPhoneBW              = 'Telefoon&nbsp;B/W';
 $zmSlangPhone                = 'Phone';
 $zmSlangPixelDiff            = 'Pixel Diff';
 $zmSlangPixels               = 'pixels';
 $zmSlangPlayAll              = 'Play All';
+$zmSlangPlay                 = 'Play';
 $zmSlangPleaseWait           = 'wacht A.U.B.';
 $zmSlangPoint                = 'Point';
 $zmSlangPostEventImageBuffer = 'Post gebeurtenis Image Buffer';
 $zmSlangPreEventImageBuffer  = 'Pre gebeurtenis Image Buffer';
+$zmSlangPreserveAspect       = 'Preserve Aspect Ratio';
 $zmSlangPreset               = 'Preset';
 $zmSlangPresets              = 'Presets';
 $zmSlangPrev                 = 'vorige';
+$zmSlangProtocol             = 'Protocol';
 $zmSlangRate                 = 'Waardering';
 $zmSlangReal                 = 'Echte';
 $zmSlangRecord               = 'Record';
@@ -509,7 +517,11 @@ $zmSlangRemoteHostPort       = 'Remote Host Poort';
 $zmSlangRemoteImageColours   = 'Remote Image kleuren';
 $zmSlangRemote               = 'Remote';
 $zmSlangRename               = 'Hernoem';
+$zmSlangReplayAll            = 'All Events';
+$zmSlangReplayGapless        = 'Gapless Events';
 $zmSlangReplay               = 'Herhaal';
+$zmSlangReplay               = 'Replay';
+$zmSlangReplaySingle         = 'Single Event';
 $zmSlangResetEventCounts     = 'Reset gebeurtenis teller';
 $zmSlangReset                = 'Reset';
 $zmSlangRestart              = 'herstart';
@@ -518,6 +530,7 @@ $zmSlangRestrictedCameraIds  = 'Verboden Camera Ids';
 $zmSlangRestrictedMonitors   = 'Restricted Monitors';
 $zmSlangReturnDelay          = 'Return Delay';
 $zmSlangReturnLocation       = 'Return Location';
+$zmSlangRewind               = 'Rewind';
 $zmSlangRotateLeft           = 'Draai linksom';
 $zmSlangRotateRight          = 'Draai rechtsom';
 $zmSlangRunMode              = 'Run Mode';
@@ -540,6 +553,7 @@ $zmSlangSet                  = 'Set';
 $zmSlangSettings             = 'Instellingen';
 $zmSlangShowFilterWindow     = 'ToonFilterWindow';
 $zmSlangShowTimeline         = 'Show Timeline';
+$zmSlangSignalCheckColour    = 'Signal Check Colour';
 $zmSlangSize                 = 'Size';
 $zmSlangSleep                = 'Sleep';
 $zmSlangSortAsc              = 'Opl.';
@@ -556,6 +570,8 @@ $zmSlangStart                = 'Start';
 $zmSlangState                = 'Status';
 $zmSlangStats                = 'Stats';
 $zmSlangStatus               = 'Status';
+$zmSlangStepBack             = 'Step Back';
+$zmSlangStepForward          = 'Step Forward';
 $zmSlangStepLarge            = 'Large Step';
 $zmSlangStepMedium           = 'Medium Step';
 $zmSlangStepNone             = 'No Step';
@@ -564,6 +580,7 @@ $zmSlangStep                 = 'Step';
 $zmSlangStills               = 'Plaatjes';
 $zmSlangStopped              = 'gestopt';
 $zmSlangStop                 = 'Stop';
+$zmSlangStreamReplayBuffer   = 'Stream Replay Image Buffer';
 $zmSlangStream               = 'Stroom';
 $zmSlangSubmit               = 'Submit';
 $zmSlangSystem               = 'Systeem';
@@ -643,13 +660,13 @@ $zmSlangZoneMinMaxBlobArea   = 'Min/Max Blob Area';
 $zmSlangZoneMinMaxBlobs      = 'Min/Max Blobs';
 $zmSlangZoneMinMaxFiltArea   = 'Min/Max Filtered Area';
 $zmSlangZoneMinMaxPixelThres = 'Min/Max Pixel Threshold (0-255)';
+$zmSlangZoneOverloadFrames   = 'Overload Frame Ignore Count';
 $zmSlangZones                = 'Zones';
 $zmSlangZone                 = 'Zone';
 $zmSlangZoomIn               = 'Zoom In';
 $zmSlangZoomOut              = 'Zoom Out';
 $zmSlangZoom                 = 'Zoom';
 
-
 // Complex replacements with formatting and/or placements, must be passed through sprintf
 $zmClangCurrentLogin         = 'huidige login is \'%1$s\'';
 $zmClangEventCount           = '%1$s %2$s'; // Als voorbeeld '37 gebeurtenissen' (from Vlang below)
