@@ -52,6 +52,7 @@ $zmSlangAttrMonitorId        = 'Id do Monitor';
 $zmSlangAttrMonitorName      = 'Nome do Monitor';
 $zmSlangAttrName             = 'Nome';
 $zmSlangAttrNotes            = 'Notes';
+$zmSlangAttrSystemLoad       = 'System Load';
 $zmSlangAttrTime             = 'Horrio';
 $zmSlangAttrTotalScore       = 'Score Total';
 $zmSlangAttrWeekday          = 'Dia/Semana';
@@ -76,10 +77,12 @@ $zmSlangBadMaxFPS            = 'Maximum FPS must be a positive integer or floati
 $zmSlangBadNameChars         = 'Nomes devem ser caracteres alfanumricos mais hfen e underscore';
 $zmSlangBadPath              = 'Path must be set to a valid value';
 $zmSlangBadPort              = 'Port must be set to a valid number';
-$zmSlangBadPostEventCount    = 'Post event image buffer must be an integer of zero or more';
-$zmSlangBadPreEventCount     = 'Pre event image buffer must be at least zero, and less than image buffer size';
-$zmSlangBadRefBlendPerc      = 'Reference blendpercentage must be a positive integer';
+$zmSlangBadPostEventCount    = 'Post event image count must be an integer of zero or more';
+$zmSlangBadPreEventCount     = 'Pre event image count must be at least zero, and less than image buffer size';
+$zmSlangBadRefBlendPerc      = 'Reference blend percentage must be a positive integer';
 $zmSlangBadSectionLength     = 'Section length must be an integer of 30 or more';
+$zmSlangBadSignalCheckColour = 'Signal check colour must be a valid RGB colour string';
+$zmSlangBadStreamReplayBuffer= 'Stream replay buffer must be an integer of zero or more';
 $zmSlangBadWarmupCount       = 'Warmup frames must be an integer of zero or more';
 $zmSlangBadWebColour         = 'Web colour must be a valid web colour string';
 $zmSlangBadWidth             = 'Width must be set to a valid value';
@@ -95,7 +98,7 @@ $zmSlangCanAutoIris          = 'Can Auto Iris';
 $zmSlangCanAutoWhite         = 'Can Auto White Bal.';
 $zmSlangCanAutoZoom          = 'Can Auto Zoom';
 $zmSlangCancel               = 'Cancelar';
-$zmSlangCancelForcedAlarm    = 'Cancelar&nbsp;Alarme&nbsp;Forado';
+$zmSlangCancelForcedAlarm    = 'Cancelar Alarme Forado';
 $zmSlangCanFocusAbs          = 'Can Focus Absolute';
 $zmSlangCanFocus             = 'Can Focus';
 $zmSlangCanFocusCon          = 'Can Focus Continuous';
@@ -217,6 +220,7 @@ $zmSlangExportMiscFiles      = 'Export Other Files (if present)';
 $zmSlangExportOptions        = 'Export Options';
 $zmSlangExportVideoFiles     = 'Export Video Files (if present)';
 $zmSlangFar                  = 'Far';
+$zmSlangFastForward          = 'Fast Forward';
 $zmSlangFeed                 = 'Alimentar';
 $zmSlangFileColours          = 'File Colours';
 $zmSlangFile                 = 'File';
@@ -235,7 +239,7 @@ $zmSlangFirst                = 'Primeiro';
 $zmSlangFlippedHori          = 'Flipped Horizontally';
 $zmSlangFlippedVert          = 'Flipped Vertically';
 $zmSlangFocus                = 'Focus';
-$zmSlangForceAlarm           = 'Forar&nbsp;Alarme';
+$zmSlangForceAlarm           = 'Forar Alarme';
 $zmSlangFormat               = 'Format';
 $zmSlangFPS                  = 'fps';
 $zmSlangFPSReportInterval    = 'Intervalo de mostragem FPS';
@@ -425,18 +429,22 @@ $zmSlangParameter            = 'Parametro';
 $zmSlangPasswordsDifferent   = 'A nova senha e a de confirmao so diferentes';
 $zmSlangPassword             = 'Senha';
 $zmSlangPaths                = 'Caminhos';
+$zmSlangPause                = 'Pause';
 $zmSlangPhoneBW              = 'Discada&nbsp;L/B';
 $zmSlangPhone                = 'Phone';
 $zmSlangPixelDiff            = 'Pixel Diff';
 $zmSlangPixels               = 'pixels';
 $zmSlangPlayAll              = 'Play All';
+$zmSlangPlay                 = 'Play';
 $zmSlangPleaseWait           = 'Por Favor Espere';
 $zmSlangPoint                = 'Point';
 $zmSlangPostEventImageBuffer = 'Buffer de imagem ps evento';
 $zmSlangPreEventImageBuffer  = 'Buffer de imagem pr evento';
+$zmSlangPreserveAspect       = 'Preserve Aspect Ratio';
 $zmSlangPreset               = 'Preset';
 $zmSlangPresets              = 'Presets';
 $zmSlangPrev                 = 'Ant.';
+$zmSlangProtocol             = 'Protocol';
 $zmSlangRate                 = 'Vel.';
 $zmSlangReal                 = 'Real';
 $zmSlangRecord               = 'Gravar';
@@ -448,6 +456,10 @@ $zmSlangRemoteHostPort       = 'Porta do host remoto';
 $zmSlangRemoteImageColours   = 'Cores de imagem remota';
 $zmSlangRemote               = 'Remoto';
 $zmSlangRename               = 'Renomear';
+$zmSlangReplayAll            = 'All Events';
+$zmSlangReplayGapless        = 'Gapless Events';
+$zmSlangReplay               = 'Replay';
+$zmSlangReplaySingle         = 'Single Event';
 $zmSlangReplay               = 'Ver Novamente';
 $zmSlangResetEventCounts     = 'Resetar contagem de eventos';
 $zmSlangReset                = 'Reset';
@@ -457,6 +469,7 @@ $zmSlangRestrictedCameraIds  = 'Ids de camera proibdos';
 $zmSlangRestrictedMonitors   = 'Restricted Monitors';
 $zmSlangReturnDelay          = 'Return Delay';
 $zmSlangReturnLocation       = 'Return Location';
+$zmSlangRewind               = 'Rewind';
 $zmSlangRotateLeft           = 'Rotacionar  esquerda ';
 $zmSlangRotateRight          = 'Rotacionar  direita';
 $zmSlangRunMode              = 'Modo de Execuo';
@@ -479,6 +492,7 @@ $zmSlangSet                  = 'Set';
 $zmSlangSettings             = 'Configuraes';
 $zmSlangShowFilterWindow     = 'MostrarJanelaDeFiltros';
 $zmSlangShowTimeline         = 'Show Timeline';
+$zmSlangSignalCheckColour    = 'Signal Check Colour';
 $zmSlangSize                 = 'Size';
 $zmSlangSleep                = 'Sleep';
 $zmSlangSortAsc              = 'Asc';
@@ -495,6 +509,8 @@ $zmSlangStart                = 'Iniciar';
 $zmSlangState                = 'Estado';
 $zmSlangStats                = 'Status';
 $zmSlangStatus               = 'Status';
+$zmSlangStepBack             = 'Step Back';
+$zmSlangStepForward          = 'Step Forward';
 $zmSlangStepLarge            = 'Large Step';
 $zmSlangStepMedium           = 'Medium Step';
 $zmSlangStepNone             = 'No Step';
@@ -504,6 +520,7 @@ $zmSlangStills               = 'Imagens';
 $zmSlangStop                 = 'Parar';
 $zmSlangStopped              = 'Parado';
 $zmSlangStream               = 'Contnuo';
+$zmSlangStreamReplayBuffer   = 'Stream Replay Image Buffer';
 $zmSlangSubmit               = 'Submit';
 $zmSlangSystem               = 'Sistema';
 $zmSlangTele                 = 'Tele';
@@ -582,13 +599,13 @@ $zmSlangZoneMinMaxBlobArea   = 'Min/Max Blob Area';
 $zmSlangZoneMinMaxBlobs      = 'Min/Max Blobs';
 $zmSlangZoneMinMaxFiltArea   = 'Min/Max Filtered Area';
 $zmSlangZoneMinMaxPixelThres = 'Min/Max Pixel Threshold (0-255)';
+$zmSlangZoneOverloadFrames   = 'Overload Frame Ignore Count';
 $zmSlangZones                = 'Zonas';
 $zmSlangZone                 = 'Zona';
 $zmSlangZoomIn               = 'Zoom In';
 $zmSlangZoomOut              = 'Zoom Out';
 $zmSlangZoom                 = 'Zoom';
 
-
 // Complex replacements with formatting and/or placements, must be passed through sprintf
 $zmClangCurrentLogin         = 'Login atual  \'%1$s\'';
 $zmClangEventCount           = '%1$s %2$s'; // For example '37 Events' (from Vlang below)
