@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web UK English language file, $Date: 2006/11/29 15:46:38 $, $Revision: 1.27 $
+// ZoneMinder web UK English language file, $Date: 2008-01-08 12:33:11 +0000 (Tue, 08 Jan 2008) $, $Revision: 2281 $
 // Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -113,6 +113,7 @@ $zmSlangAttrMonitorName      = ' ';
 $zmSlangAttrMontage          = '';
 $zmSlangAttrName             = 'Name';
 $zmSlangAttrNotes            = 'Notes';
+$zmSlangAttrSystemLoad       = 'System Load';
 $zmSlangAttrTime             = '';
 $zmSlangAttrTotalScore       = '. ';
 $zmSlangAttrWeekday          = ' ';
@@ -137,10 +138,12 @@ $zmSlangBadMaxFPS            = 'Maximum FPS must be a positive integer or floati
 $zmSlangBadNameChars         = 'Names may only contain alphanumeric characters plus hyphen and underscore';
 $zmSlangBadPath              = 'Path must be set to a valid value';
 $zmSlangBadPort              = 'Port must be set to a valid number';
-$zmSlangBadPostEventCount    = 'Post event image buffer must be an integer of zero or more';
-$zmSlangBadPreEventCount     = 'Pre event image buffer must be at least zero, and less than image buffer size';
-$zmSlangBadRefBlendPerc      = 'Reference blendpercentage must be a positive integer';
+$zmSlangBadPostEventCount    = 'Post event image count must be an integer of zero or more';
+$zmSlangBadPreEventCount     = 'Pre event image count must be at least zero, and less than image buffer size';
+$zmSlangBadRefBlendPerc      = 'Reference blend percentage must be a positive integer';
 $zmSlangBadSectionLength     = 'Section length must be an integer of 30 or more';
+$zmSlangBadSignalCheckColour = 'Signal check colour must be a valid RGB colour string';
+$zmSlangBadStreamReplayBuffer= 'Stream replay buffer must be an integer of zero or more';
 $zmSlangBadWarmupCount       = 'Warmup frames must be an integer of zero or more';
 $zmSlangBadWebColour         = 'Web colour must be a valid web colour string';
 $zmSlangBadWidth             = 'Width must be set to a valid value';
@@ -156,7 +159,7 @@ $zmSlangCanAutoIris          = 'Can Auto Iris';
 $zmSlangCanAutoWhite         = 'Can Auto White Bal.';
 $zmSlangCanAutoZoom          = 'Can Auto Zoom';
 $zmSlangCancel               = '';
-$zmSlangCancelForcedAlarm    = '&nbsp;&nbsp;';
+$zmSlangCancelForcedAlarm    = '  ';
 $zmSlangCanFocusAbs          = 'Can Focus Absolute';
 $zmSlangCanFocus             = 'Can Focus';
 $zmSlangCanFocusCon          = 'Can Focus Continuous';
@@ -278,6 +281,7 @@ $zmSlangExportMiscFiles      = 'Export Other Files (if present)';
 $zmSlangExportOptions        = 'Export Options';
 $zmSlangExportVideoFiles     = 'Export Video Files (if present)';
 $zmSlangFar                  = 'Far';
+$zmSlangFastForward          = 'Fast Forward';
 $zmSlangFeed                 = 'Feed';
 $zmSlangFileColours          = 'File Colours';
 $zmSlangFile                 = 'File';
@@ -296,7 +300,7 @@ $zmSlangFirst                = '';
 $zmSlangFlippedHori          = 'Flipped Horizontally';
 $zmSlangFlippedVert          = 'Flipped Vertically';
 $zmSlangFocus                = 'Focus';
-$zmSlangForceAlarm           = '&nbsp;';
+$zmSlangForceAlarm           = ' ';
 $zmSlangFormat               = 'Format';
 $zmSlangFPS                  = '/c';
 $zmSlangFPSReportInterval    = '   ';
@@ -486,18 +490,22 @@ $zmSlangParameter            = '';
 $zmSlangPassword             = '';
 $zmSlangPasswordsDifferent   = '  ';
 $zmSlangPaths                = '';
+$zmSlangPause                = 'Pause';
 $zmSlangPhoneBW              = ' ';
 $zmSlangPhone                = 'Phone';
 $zmSlangPixelDiff            = 'Pixel Diff';
 $zmSlangPixels               = ' ';
 $zmSlangPlayAll              = 'Play All';
+$zmSlangPlay                 = 'Play';
 $zmSlangPleaseWait           = ' ';
 $zmSlangPoint                = 'Point';
 $zmSlangPostEventImageBuffer = '  ';
 $zmSlangPreEventImageBuffer  = '  ';
+$zmSlangPreserveAspect       = 'Preserve Aspect Ratio';
 $zmSlangPreset               = 'Preset';
 $zmSlangPresets              = 'Presets';
 $zmSlangPrev                 = '.';
+$zmSlangProtocol             = 'Protocol';
 $zmSlangRate                 = '';
 $zmSlangReal                 = '';
 $zmSlangRecord               = 'Record';
@@ -510,6 +518,10 @@ $zmSlangRemoteHostPort       = ' ';
 $zmSlangRemoteImageColours   = '   ';
 $zmSlangRename               = '';
 $zmSlangReplay               = '';
+$zmSlangReplayAll            = 'All Events';
+$zmSlangReplayGapless        = 'Gapless Events';
+$zmSlangReplay               = 'Replay';
+$zmSlangReplaySingle         = 'Single Event';
 $zmSlangResetEventCounts     = '  ';
 $zmSlangReset                = 'Reset';
 $zmSlangRestart              = '';
@@ -518,6 +530,7 @@ $zmSlangRestrictedCameraIds  = 'Id  ';
 $zmSlangRestrictedMonitors   = 'Restricted Monitors';
 $zmSlangReturnDelay          = 'Return Delay';
 $zmSlangReturnLocation       = 'Return Location';
+$zmSlangRewind               = 'Rewind';
 $zmSlangRotateLeft           = ' ';
 $zmSlangRotateRight          = ' ';
 $zmSlangRunMode              = ' ';
@@ -540,6 +553,7 @@ $zmSlangSet                  = 'Set';
 $zmSlangSettings             = '';
 $zmSlangShowFilterWindow     = '  ';
 $zmSlangShowTimeline         = 'Show Timeline';
+$zmSlangSignalCheckColour    = 'Signal Check Colour';
 $zmSlangSize                 = 'Size';
 $zmSlangSleep                = 'Sleep';
 $zmSlangSortAsc              = 'Asc';
@@ -556,6 +570,8 @@ $zmSlangStart                = '';
 $zmSlangState                = '';
 $zmSlangStats                = '';
 $zmSlangStatus               = '';
+$zmSlangStepBack             = 'Step Back';
+$zmSlangStepForward          = 'Step Forward';
 $zmSlangStepLarge            = 'Large Step';
 $zmSlangStepMedium           = 'Medium Step';
 $zmSlangStepNone             = 'No Step';
@@ -565,6 +581,7 @@ $zmSlangStills               = '-';
 $zmSlangStop                 = '';
 $zmSlangStopped              = '';
 $zmSlangStream               = '';
+$zmSlangStreamReplayBuffer   = 'Stream Replay Image Buffer';
 $zmSlangSubmit               = 'Submit';
 $zmSlangSystem               = '';
 $zmSlangTele                 = 'Tele';
@@ -644,12 +661,12 @@ $zmSlangZoneMinMaxBlobArea   = 'Min/Max Blob Area';
 $zmSlangZoneMinMaxBlobs      = 'Min/Max Blobs';
 $zmSlangZoneMinMaxFiltArea   = 'Min/Max Filtered Area';
 $zmSlangZoneMinMaxPixelThres = 'Min/Max Pixel Threshold (0-255)';
+$zmSlangZoneOverloadFrames   = 'Overload Frame Ignore Count';
 $zmSlangZones                = '';
 $zmSlangZoomIn               = 'Zoom In';
 $zmSlangZoomOut              = 'Zoom Out';
 $zmSlangZoom                 = 'Zoom';
 
-
 // Complex replacements with formatting and/or placements, must be passed through sprintf
 $zmClangCurrentLogin         = ' : \'%1$s\'';
 $zmClangEventCount           = '%1$s %2$s'; // For example '37 Events' (from Vlang below)
