@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web error view file, $Date: 2006/11/09 10:55:41 $, $Revision: 1.8 $
+// ZoneMinder web error view file, $Date: 2008-02-20 23:11:25 +0000 (Wed, 20 Feb 2008) $, $Revision: 2314 $
 // Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -18,7 +18,11 @@
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 //
 
+noCacheHeaders();
+header("Content-type: application/xhtml+xml" );
+echo( '<?xml version="1.0" encoding="iso-8859-1"?>'."\n" );
 ?>
+<!DOCTYPE html PUBLIC "-//WAPFORUM//DTD XHTML Mobile 1.0//EN" "http://www.wapforum.org/DTD/xhtml-mobile10.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
 <title><?= ZM_WEB_TITLE_PREFIX ?> - <?= $zmSlangError ?></title>
